function [ret,x0,str,ts,xts]=nanolink(t,x,u,flag);
%NANOLINK	is the M-file description of the SIMULINK system named NANOLINK.
%	The block-diagram can be displayed by typing: NANOLINK.
%
%	SYS=NANOLINK(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes NANOLINK to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling NANOLINK with a FLAG of zero:
%	[SIZES]=NANOLINK([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[100,100,600,400])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     '999999')
set_param(sys,'Min step size', '0.0001')
set_param(sys,'Max step size', '10')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')


%     Subsystem  'Subsystem5'.

new_system([sys,'/','Subsystem5'])
set_param([sys,'/','Subsystem5'],'Location',[307,509,1144,814])
open_system([sys,'/','Subsystem5'])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain1'])
set_param([sys,'/','Subsystem5/Gain1'],...
		'hide name',0,...
		'Gain','1-pulse',...
		'position',[220,170,355,210])

add_block('built-in/Sum',[sys,'/','Subsystem5/Sum1'])
set_param([sys,'/','Subsystem5/Sum1'],...
		'hide name',0,...
		'position',[525,69,545,231])

add_block('built-in/Gain',[sys,'/','Subsystem5/Gain2'])
set_param([sys,'/','Subsystem5/Gain2'],...
		'hide name',0,...
		'Gain','pulse',...
		'position',[340,90,475,130])


%     Subsystem  'Subsystem5/Subsystem5'.

new_system([sys,'/','Subsystem5/Subsystem5'])
set_param([sys,'/','Subsystem5/Subsystem5'],'Location',[580,281,938,501])
open_system([sys,'/','Subsystem5/Subsystem5'])

add_block('built-in/Note',[sys,'/','Subsystem5/Subsystem5/CRENEAU'])
set_param([sys,'/','Subsystem5/Subsystem5/CRENEAU'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[155,25,160,30])

add_block('built-in/Outport',[sys,'/','Subsystem5/Subsystem5/out_1'])
set_param([sys,'/','Subsystem5/Subsystem5/out_1'],...
		'position',[295,100,315,120])

add_block('built-in/Product',[sys,'/','Subsystem5/Subsystem5/Product'])
set_param([sys,'/','Subsystem5/Subsystem5/Product'],...
		'hide name',0,...
		'position',[230,64,250,151])

add_block('built-in/Inport',[sys,'/','Subsystem5/Subsystem5/in_1'])
set_param([sys,'/','Subsystem5/Subsystem5/in_1'],...
		'position',[115,75,135,95])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem5/Subsystem5/MATLAB Fcn'])
set_param([sys,'/','Subsystem5/Subsystem5/MATLAB Fcn'],...
		'MATLAB Fcn','creneau(u)',...
		'Output Width','1',...
		'position',[120,113,180,147])

add_block('built-in/Clock',[sys,'/','Subsystem5/Subsystem5/Clock'])
set_param([sys,'/','Subsystem5/Subsystem5/Clock'],...
		'BackGround',7,...
		'position',[45,113,80,147])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/Subsystem5/To Workspace3'])
set_param([sys,'/','Subsystem5/Subsystem5/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','creneau',...
		'buffer','points_trace',...
		'position',[245,178,340,192])
add_line([sys,'/','Subsystem5/Subsystem5'],[140,85;225,85])
add_line([sys,'/','Subsystem5/Subsystem5'],[255,110;290,110])
add_line([sys,'/','Subsystem5/Subsystem5'],[185,130;225,130])
add_line([sys,'/','Subsystem5/Subsystem5'],[85,130;115,130])
add_line([sys,'/','Subsystem5/Subsystem5'],[205,130;205,185;240,185])
set_param([sys,'/','Subsystem5/Subsystem5'],...
		'Mask Display','COUPURES\nMAGNETOMETRES\nDE MESURES')


%     Finished composite block 'Subsystem5/Subsystem5'.

set_param([sys,'/','Subsystem5/Subsystem5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[190,84,315,136])

add_block('built-in/Inport',[sys,'/','Subsystem5/in_1'])
set_param([sys,'/','Subsystem5/in_1'],...
		'position',[65,100,85,120])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux'])
set_param([sys,'/','Subsystem5/Demux'],...
		'outputs','3',...
		'position',[140,39,180,71])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace2'])
set_param([sys,'/','Subsystem5/To Workspace2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','com_avant',...
		'buffer','points_trace',...
		'position',[205,38,295,52])

add_block('built-in/Outport',[sys,'/','Subsystem5/out_1'])
set_param([sys,'/','Subsystem5/out_1'],...
		'position',[635,140,655,160])

add_block('built-in/To Workspace',[sys,'/','Subsystem5/To Workspace3'])
set_param([sys,'/','Subsystem5/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','com_apres',...
		'buffer','points_trace',...
		'position',[650,28,745,42])

add_block('built-in/Demux',[sys,'/','Subsystem5/Demux1'])
set_param([sys,'/','Subsystem5/Demux1'],...
		'outputs','3',...
		'position',[585,29,625,61])
add_line([sys,'/','Subsystem5'],[90,110;185,110])
add_line([sys,'/','Subsystem5'],[90,110;125,110;125,190;215,190])
add_line([sys,'/','Subsystem5'],[480,110;520,110])
add_line([sys,'/','Subsystem5'],[360,190;520,190])
add_line([sys,'/','Subsystem5'],[320,110;335,110])
add_line([sys,'/','Subsystem5'],[550,150;630,150])
add_line([sys,'/','Subsystem5'],[185,45;200,45])
add_line([sys,'/','Subsystem5'],[105,110;105,55;135,55])
add_line([sys,'/','Subsystem5'],[630,35;645,35])
add_line([sys,'/','Subsystem5'],[495,110;495,45;580,45])
set_param([sys,'/','Subsystem5'],...
		'Mask Display','PULSE\noui/non')


%     Finished composite block 'Subsystem5'.

set_param([sys,'/','Subsystem5'],...
		'hide name',0,...
		'position',[95,28,240,82])


%     Subsystem  'Subsystem6'.

new_system([sys,'/','Subsystem6'])
set_param([sys,'/','Subsystem6'],'Location',[580,281,938,501])

add_block('built-in/Note',[sys,'/','Subsystem6/CRENEAU'])
set_param([sys,'/','Subsystem6/CRENEAU'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[155,25,160,30])

add_block('built-in/Outport',[sys,'/','Subsystem6/out_1'])
set_param([sys,'/','Subsystem6/out_1'],...
		'position',[295,100,315,120])

add_block('built-in/Product',[sys,'/','Subsystem6/Product'])
set_param([sys,'/','Subsystem6/Product'],...
		'hide name',0,...
		'position',[230,64,250,151])

add_block('built-in/Inport',[sys,'/','Subsystem6/in_1'])
set_param([sys,'/','Subsystem6/in_1'],...
		'position',[115,75,135,95])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem6/MATLAB Fcn'])
set_param([sys,'/','Subsystem6/MATLAB Fcn'],...
		'MATLAB Fcn','creneau(u)',...
		'Output Width','1',...
		'position',[120,113,180,147])

add_block('built-in/Clock',[sys,'/','Subsystem6/Clock'])
set_param([sys,'/','Subsystem6/Clock'],...
		'BackGround',7,...
		'position',[45,113,80,147])

add_block('built-in/To Workspace',[sys,'/','Subsystem6/To Workspace3'])
set_param([sys,'/','Subsystem6/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','creneau',...
		'buffer','points_trace',...
		'position',[245,178,340,192])
add_line([sys,'/','Subsystem6'],[140,85;225,85])
add_line([sys,'/','Subsystem6'],[255,110;290,110])
add_line([sys,'/','Subsystem6'],[185,130;225,130])
add_line([sys,'/','Subsystem6'],[85,130;115,130])
add_line([sys,'/','Subsystem6'],[205,130;205,185;240,185])
set_param([sys,'/','Subsystem6'],...
		'Mask Display','COUPURES\nMAGNETOMETRES\nDE MESURES')


%     Finished composite block 'Subsystem6'.

set_param([sys,'/','Subsystem6'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[100,129,225,181])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
