function [ret,x0,str,ts,xts]=regderb1(t,x,u,flag);
%REGDERB1	is the M-file description of the SIMULINK system named REGDERB1.
%	The block-diagram can be displayed by typing: REGDERB1.
%
%	SYS=REGDERB1(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes REGDERB1 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling REGDERB1 with a FLAG of zero:
%	[SIZES]=REGDERB1([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,50,1267,977])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    'instant_injection')
set_param(sys,'Stop time',     '7000')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '1')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')
set_param(sys,'Nonreal-time algorithm','n')

add_block('built-in/Note',[sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'PHASE DE DETUMBLING']])
set_param([sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'PHASE DE DETUMBLING']],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[678,0,683,5])

add_block('built-in/Note',[sys,'/',['SIMULATION regderb1.m',13,'( Contrle de p et r par 3 magntocoupleurs + roue tangage ',13,'( Rappel proportionnel sur la vitesse absolue q et le tangage teta )',13,'']])
set_param([sys,'/',['SIMULATION regderb1.m',13,'( Contrle de p et r par 3 magntocoupleurs + roue tangage ',13,'( Rappel proportionnel sur la vitesse absolue q et le tangage teta )',13,'']],...
		'ForeGround',3,...
		'Font Name','Arial')
set_param([sys,'/',['SIMULATION regderb1.m',13,'( Contrle de p et r par 3 magntocoupleurs + roue tangage ',13,'( Rappel proportionnel sur la vitesse absolue q et le tangage teta )',13,'']],...
		'Font Weight','bold',...
		'Font Size',18)
set_param([sys,'/',['SIMULATION regderb1.m',13,'( Contrle de p et r par 3 magntocoupleurs + roue tangage ',13,'( Rappel proportionnel sur la vitesse absolue q et le tangage teta )',13,'']],...
		'position',[625,60,630,65])

add_block('built-in/Note',[sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE',13,'']])
set_param([sys,'/',['UTILISATION DU QUATERNION D''ATTITUDE',13,'']],...
		'ForeGround',5,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22,...
		'position',[670,145,675,150])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx, my, mz',...
		'Mask Dialogue','eval(''plot(temps,mx_deriv,temps,my_deriv,temps,mz_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[380,695,605,756])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[635,780,810,846])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[130,695,330,761])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,50,1012,686])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=magenta\nlacet=cyan')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[375,765,605,851])

add_block('built-in/Note',[sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[475,640,480,645])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[655,575,660,580])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[245,580,250,585])

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[430,555,435,560])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[485,310,490,315])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[475,490,480,495])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[185,438,400,542])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[560,274,620,561])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','[vp0 vq0 vr0 qt00 qt10 qt20 qt30]',...
		'position',[685,394,785,446])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[580,325,585,330])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[575,465,580,470])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[850,325,855,330])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,50,1267,977])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn1'])
set_param([sys,'/','Subsystem/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[905,670,910,675])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[815,621,895,659])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[705,590,710,595])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[850,370,920,390])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn3'])
set_param([sys,'/','Subsystem/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Fcn',[sys,'/','Subsystem/Fcn'])
set_param([sys,'/','Subsystem/Fcn'],...
		'Expr','(u(1)^2+u(3)^2)^0.5',...
		'position',[720,325,760,345])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace9'])
set_param([sys,'/','Subsystem/To Workspace9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p2plusq2',...
		'buffer','points_trace',...
		'position',[805,325,875,345])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[400,415,420,435])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,365,425,370])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To File',[sys,'/','Subsystem/To File'])
set_param([sys,'/','Subsystem/To File'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','roulis',...
		'position',[1115,377,1205,423])

add_block('built-in/To File',[sys,'/','Subsystem/To File1'])
set_param([sys,'/','Subsystem/To File1'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','tangage',...
		'position',[1115,427,1205,473])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace8'])
set_param([sys,'/','Subsystem/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[965,525,1035,545])

add_block('built-in/To File',[sys,'/','Subsystem/To File2'])
set_param([sys,'/','Subsystem/To File2'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','lacet',...
		'position',[1115,492,1205,538])

add_block('built-in/To File',[sys,'/','Subsystem/To File3'])
set_param([sys,'/','Subsystem/To File3'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','temps',...
		'position',[1115,547,1205,593])

add_block('built-in/Clock',[sys,'/','Subsystem/Clock'])
set_param([sys,'/','Subsystem/Clock'],...
		'position',[905,525,925,545])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace10'])
set_param([sys,'/','Subsystem/To Workspace10'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_tmc',...
		'buffer','points_trace',...
		'position',[800,272,900,298])

add_block('built-in/Note',[sys,'/','Subsystem/Vrifications Poinsot'])
set_param([sys,'/','Subsystem/Vrifications Poinsot'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[965,295,970,300])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux3'])
set_param([sys,'/','Subsystem/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace15'])
set_param([sys,'/','Subsystem/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[715,165,785,185])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace16'])
set_param([sys,'/','Subsystem/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[715,200,785,220])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace17'])
set_param([sys,'/','Subsystem/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[715,235,785,255])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']])
set_param([sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']],...
		'position',[895,185,900,190])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[780,452,805,478])

add_block('built-in/Scope',[sys,'/','Subsystem/Scope'])
set_param([sys,'/','Subsystem/Scope'],...
		'Vgain','0.004000',...
		'Hgain','50000.000000',...
		'Vmax','0.008000',...
		'Hmax','100000.000000',...
		'Window',[314,357,1072,908],...
		'position',[865,130,895,160])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[930,624,1015,656])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])


%     Subsystem  'Subsystem/Angles en degrs'.

new_system([sys,'/','Subsystem/Angles en degrs'])
set_param([sys,'/','Subsystem/Angles en degrs'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Subsystem/Angles en degrs/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/Angles en degrs/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Subsystem/Angles en degrs/x'])
set_param([sys,'/','Subsystem/Angles en degrs/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Subsystem/Angles en degrs'],[90,65;125,65])
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Entries','7000\/-200\/200\/''y-/m--/c-./w:g*/ro/b+''\/')


%     Finished composite block 'Subsystem/Angles en degrs'.

set_param([sys,'/','Subsystem/Angles en degrs'],...
		'orientation',2,...
		'position',[710,512,825,558])


%     Subsystem  'Subsystem/Vitesses angulaires en rd//s'.

new_system([sys,'/','Subsystem/Vitesses angulaires en rd//s'])
set_param([sys,'/','Subsystem/Vitesses angulaires en rd//s'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['Subsystem/Vitesses angulaires en rd//s/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/Vitesses angulaires en rd//s/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','Subsystem/Vitesses angulaires en rd//s/x'])
set_param([sys,'/','Subsystem/Vitesses angulaires en rd//s/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','Subsystem/Vitesses angulaires en rd//s'],[90,65;125,65])
set_param([sys,'/','Subsystem/Vitesses angulaires en rd//s'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Subsystem/Vitesses angulaires en rd//s'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Subsystem/Vitesses angulaires en rd//s'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Subsystem/Vitesses angulaires en rd//s'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Subsystem/Vitesses angulaires en rd//s'],...
		'Mask Entries','7000\/-0.1\/0.1\/''y-/m--/c-./w:g*/ro/b+''\/')


%     Finished composite block 'Subsystem/Vitesses angulaires en rd//s'.

set_param([sys,'/','Subsystem/Vitesses angulaires en rd//s'],...
		'orientation',2,...
		'position',[350,187,465,233])
add_line([sys,'/','Subsystem'],[525,380;740,380])
add_line([sys,'/','Subsystem'],[830,380;845,380])
add_line([sys,'/','Subsystem'],[425,425;465,425])
add_line([sys,'/','Subsystem'],[525,465;695,465])
add_line([sys,'/','Subsystem'],[930,535;960,535])
add_line([sys,'/','Subsystem'],[660,380;660,335;715,335])
add_line([sys,'/','Subsystem'],[765,335;800,335])
add_line([sys,'/','Subsystem'],[660,335;660,285;795,285])
add_line([sys,'/','Subsystem'],[415,625;465,625])
add_line([sys,'/','Subsystem'],[525,580;560,580])
add_line([sys,'/','Subsystem'],[525,665;730,665])
add_line([sys,'/','Subsystem'],[675,465;675,615;730,615])
add_line([sys,'/','Subsystem'],[775,640;810,640])
add_line([sys,'/','Subsystem'],[900,640;925,640])
add_line([sys,'/','Subsystem'],[765,465;775,465])
add_line([sys,'/','Subsystem'],[810,465;855,465])
add_line([sys,'/','Subsystem'],[910,430;960,430])
add_line([sys,'/','Subsystem'],[910,465;960,465])
add_line([sys,'/','Subsystem'],[910,500;960,500])
add_line([sys,'/','Subsystem'],[945,430;945,400;1110,400])
add_line([sys,'/','Subsystem'],[943,465;945,450;1110,450])
add_line([sys,'/','Subsystem'],[945,500;945,515;1110,515])
add_line([sys,'/','Subsystem'],[930,535;930,570;1110,570])
add_line([sys,'/','Subsystem'],[550,380;550,210;605,210])
add_line([sys,'/','Subsystem'],[660,175;710,175])
add_line([sys,'/','Subsystem'],[660,210;710,210])
add_line([sys,'/','Subsystem'],[660,245;710,245])
add_line([sys,'/','Subsystem'],[685,210;685,145;860,145])
add_line([sys,'/','Subsystem'],[550,210;470,210])
add_line([sys,'/','Subsystem'],[845,465;845,535;830,535])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[905,301,1100,374])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[51,209,1222,876])

add_block('built-in/Note',[sys,'/','UnNamed1/F(X,t) POUR LA DERIVEE DE LA ROTATION ABSOLUE'])
set_param([sys,'/','UnNamed1/F(X,t) POUR LA DERIVEE DE LA ROTATION ABSOLUE'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Size',24,...
		'position',[590,15,595,20])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']])
set_param([sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[710,357,810,403])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain3'])
set_param([sys,'/','UnNamed1/Gain3'],...
		'hide name',0,...
		'position',[860,363,900,397])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression de',13,'tous les couples']])
set_param([sys,'/',['UnNamed1/Suppression de',13,'tous les couples']],...
		'position',[870,310,875,315])

add_block('built-in/Note',[sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[55,380,60,385])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression',13,'perturbations']])
set_param([sys,'/',['UnNamed1/Suppression',13,'perturbations']],...
		'position',[530,515,535,520])

add_block('built-in/Note',[sys,'/','UnNamed1/p q r'])
set_param([sys,'/','UnNamed1/p q r'],...
		'position',[270,410,275,415])


%     Subsystem  'UnNamed1/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem'],'Location',[104,168,1149,834])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Quaternion'])
set_param([sys,'/','UnNamed1/Subsystem/Quaternion'],...
		'position',[200,160,205,165])


%     Subsystem  'UnNamed1/Subsystem/Subsystem2'.

new_system([sys,'/','UnNamed1/Subsystem/Subsystem2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2'],'Location',[4,50,1267,977])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace3'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','mz_deriv',...
		'buffer','points_trace',...
		'position',[685,500,765,520])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace2'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','my_deriv',...
		'buffer','points_trace',...
		'position',[685,470,765,490])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace1'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','mx_deriv',...
		'buffer','points_trace',...
		'position',[685,440,765,460])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem/Subsystem2/Demux1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Demux1'],...
		'orientation',2,...
		'outputs','3',...
		'position',[795,435,845,525])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Gain pour',13,'avoir le bon signe',13,'des produits vectoriels']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Gain pour',13,'avoir le bon signe',13,'des produits vectoriels']],...
		'position',[475,160,480,165])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem2/Gain5'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Gain5'],...
		'Gain','-1',...
		'position',[450,216,485,244])


%     Subsystem  'UnNamed1/Subsystem/Subsystem2/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],'Location',[4,50,1267,977])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Subsystem/B',13,'axes satellite']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Subsystem/B',13,'axes satellite']],...
		'position',[500,110,505,115])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/MATLAB Fcn2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/MATLAB Fcn2'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','quatbmgn(u)',...
		'Output Width','3',...
		'position',[410,77,475,113])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/( B,Q )'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/( B,Q )'],...
		'position',[380,70,385,75])

add_block('built-in/Clock',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/Clock'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/Clock'],...
		'position',[60,55,80,75])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/Mux2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/Mux2'],...
		'inputs','[3 4]',...
		'position',[320,39,350,146])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/MATLAB Fcn'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3',...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[110,40,285,90])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/out_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/out_1'],...
		'position',[525,85,545,105])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem/in_1'],...
		'position',[60,110,80,130])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],[355,95;405,95])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],[290,65;315,65])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],[85,65;105,65])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],[480,95;520,95])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],[85,120;315,120])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],...
		'Mask Display','CHAMP MAGNETIQUE\nEN AXES SATELLITE\nA PARTIR DU CHAMP \nEN AXES ORBITAUX\nET DU QUATERNION D''ATTITUDE')


%     Finished composite block 'UnNamed1/Subsystem/Subsystem2/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Subsystem'],...
		'hide name',0,...
		'position',[140,232,350,328])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem2/Gain4'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Gain4'],...
		'Gain','0',...
		'position',[230,376,265,404])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem/Subsystem2/Demux'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Demux'],...
		'outputs','3',...
		'position',[145,345,195,435])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem/Subsystem2/Mux'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Mux'],...
		'inputs','3',...
		'position',[295,344,325,436])


%     Subsystem  ['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire'].

new_system([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],'Location',[33,479,253,634])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/in_1']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/in_1']],...
		'position',[15,25,35,45])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/in_2']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/out_1']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/Sum']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Product',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/Product']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire/Product']],...
		'position',[65,55,90,75])
add_line([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],[150,65;180,65])
add_line([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],[95,65;120,65])
add_line([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],[40,35;60,60])
add_line([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],[40,100;60,70])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire'].

set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Inner',13,'Produit',13,'scalaire']],...
		'position',[405,321,420,414])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem2/omega*'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/omega*'],...
		'position',[360,365,365,370])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn2'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','u/(norm(u))^2',...
		'Output Width','3',...
		'Mask Display','B/norm(B)')
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn2'],...
		'position',[400,260,485,300])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Rotationtransversale',13,'de px+rz']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Rotationtransversale',13,'de px+rz']],...
		'inputs','-+',...
		'position',[570,264,595,511])

add_block('built-in/Product',[sys,'/','UnNamed1/Subsystem/Subsystem2/Product'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Product'],...
		'position',[505,236,540,414])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem2/B'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/B'],...
		'position',[380,255,385,260])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/Subsystem2/in_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/in_1'],...
		'position',[85,270,105,290])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/Subsystem2/in_2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/in_2'],...
		'Port','2',...
		'position',[85,380,105,400])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Subsystem/Subsystem2/',13,'mux']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/',13,'mux']],...
		'inputs','[3 3]',...
		'position',[630,268,660,432])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn3'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[675,332,740,368])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Moment',13,'magntique']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Moment',13,'magntique']],...
		'position',[710,370,715,375])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem2/gain_magneto'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/gain_magneto'],...
		'Gain','1e6',...
		'position',[775,376,810,404])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem/Subsystem2/out_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/out_1'],...
		'position',[1175,340,1195,360])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn4'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[1075,332,1140,368])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem/Subsystem2/Mux3'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/Mux3'],...
		'inputs','[3 3]',...
		'position',[1005,268,1035,432])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/To Workspace'],...
		'orientation',2,...
		'hide name',0,...
		'mat-name','cpl_deriv',...
		'buffer','points_trace',...
		'position',[1060,255,1140,275])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn5'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','saturmom(u)',...
		'Output Width','3',...
		'Mask Display','LIMITEUR\nPROPORTIONNEL\nA 0.2 Am')
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/MATLAB Fcn5'],...
		'position',[835,368,965,412])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem2/M (3 )_'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/M (3 )_'],...
		'position',[990,360,995,365])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem2/B ( 3 )'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2/B ( 3 )'],...
		'position',[975,280,980,285])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Couple',13,'magntique']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Couple',13,'magntique']],...
		'position',[1105,295,1110,300])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem2/Produit vectoriel',13,'M, B']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/Produit vectoriel',13,'M, B']],...
		'position',[1105,370,1110,375])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem2/CALCUL DU COUPLE MAGNETIQUE BASE SUR LA DERIVEE DE B',13,'CONCERNANT UNIQUEMENT LE ROULIS ET LE TANGAGE']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/CALCUL DU COUPLE MAGNETIQUE BASE SUR LA DERIVEE DE B',13,'CONCERNANT UNIQUEMENT LE ROULIS ET LE TANGAGE']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem2/CALCUL DU COUPLE MAGNETIQUE BASE SUR LA DERIVEE DE B',13,'CONCERNANT UNIQUEMENT LE ROULIS ET LE TANGAGE']],...
		'Font Size',18,...
		'position',[635,50,640,55])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[745,350;755,350;755,390;770,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[1145,350;1170,350])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[1155,350;1145,265])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[790,510;770,510])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[790,480;770,480])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[790,450;770,450])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[1040,350;1070,350])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[490,230;615,230;625,310])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[615,230;736,230;735,310;1000,310])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[355,280;395,280])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[370,280;370,230;445,230])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[665,350;670,350])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[600,390;625,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[330,390;400,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[360,390;360,450;565,450])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[545,325;565,325])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[490,280;500,280])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[425,370;500,370])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[365,280;365,345;400,345])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[200,420;290,420])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[200,360;290,360])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[270,390;290,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[200,390;225,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[110,280;135,280])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[110,390;140,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[815,390;830,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[970,390;1000,390])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem2'],[990,390;990,480;850,480])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem2'],...
		'Mask Display','CONTRLE\nPAR MAGNETOCOUPLEURS\n\nDES COMPOSANTES p,  r')


%     Finished composite block 'UnNamed1/Subsystem/Subsystem2'.

set_param([sys,'/','UnNamed1/Subsystem/Subsystem2'],...
		'hide name',0,...
		'position',[270,165,475,245])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/p q r'])
set_param([sys,'/','UnNamed1/Subsystem/p q r'],...
		'position',[200,245,205,250])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Rotation'])
set_param([sys,'/','UnNamed1/Subsystem/Rotation'],...
		'position',[200,225,205,230])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem/in_1'],...
		'hide name',0,...
		'position',[85,173,105,197])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/in_2'])
set_param([sys,'/','UnNamed1/Subsystem/in_2'],...
		'hide name',0,...
		'Port','2',...
		'position',[90,215,110,235])


%     Subsystem  'UnNamed1/Subsystem/Subsystem1'.

new_system([sys,'/','UnNamed1/Subsystem/Subsystem1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1'],'Location',[131,349,1038,893])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem1/COMMANDE DE LA ROUE DE TANGAGE'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/COMMANDE DE LA ROUE DE TANGAGE'],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[485,25,490,30])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem1/Rappel proportionnel',13,' la',13,'rotation q']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem1/Rappel proportionnel',13,' la',13,'rotation q']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[500,75,505,80])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem/Subsystem1/Mux4'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Mux4'],...
		'hide name',0,...
		'inputs','3',...
		'position',[505,157,540,273])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem1/Rappel proportionnel',13,'au',13,'tangage']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem1/Rappel proportionnel',13,'au',13,'tangage']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[360,440,365,445])

add_block('built-in/Mux',[sys,'/','UnNamed1/Subsystem/Subsystem1/Mux5'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Mux5'],...
		'hide name',0,...
		'inputs','3',...
		'position',[505,312,540,428])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem1/To Workspace6'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/To Workspace6'],...
		'hide name',0,...
		'mat-name','cpl_roue_teta',...
		'buffer','points_trace',...
		'position',[405,340,485,360])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem1/Gain10'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Gain10'],...
		'hide name',0,...
		'Gain','0',...
		'position',[305,316,340,344])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem1/Gain9'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Gain9'],...
		'hide name',0,...
		'Gain','0',...
		'position',[305,396,340,424])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem1/Gain8'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Gain8'],...
		'hide name',0,...
		'Gain','-4e-6',...
		'position',[295,352,375,388])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem/Subsystem1/MATLAB Fcn'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/MATLAB Fcn'],...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[115,353,175,387])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem1/To Workspace5'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/To Workspace5'],...
		'hide name',0,...
		'mat-name','cpl_roue_q',...
		'buffer','points_trace',...
		'position',[335,180,415,200])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Subsystem1/Roue'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Roue'],...
		'hide name',0,...
		'position',[275,110,280,115])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/Subsystem1/in_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/in_1'],...
		'hide name',0,...
		'position',[75,205,95,225])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem/Subsystem1/Demux3'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Demux3'],...
		'hide name',0,...
		'outputs','3',...
		'position',[135,157,175,273])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem1/Gain6'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Gain6'],...
		'hide name',0,...
		'Gain','0',...
		'position',[215,161,250,189])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem1/Gain7'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Gain7'],...
		'hide name',0,...
		'Gain','0',...
		'position',[215,241,250,269])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem/Subsystem1/out_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/out_1'],...
		'hide name',0,...
		'position',[830,305,850,325])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem/Subsystem1/Sum'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Sum'],...
		'hide name',0,...
		'position',[640,267,685,358])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/Subsystem1/in_2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/in_2'],...
		'hide name',0,...
		'Port','2',...
		'position',[65,360,85,380])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem/Subsystem1/Demux4'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Demux4'],...
		'hide name',0,...
		'outputs','3',...
		'position',[195,312,235,428])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem1/gain_roue'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/gain_roue'],...
		'hide name',0,...
		'Gain','-1e-3',...
		'position',[225,190,295,240])

add_block('built-in/Saturation',[sys,'/','UnNamed1/Subsystem/Subsystem1/Saturation'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/Saturation'],...
		'Lower Limit','-4e-6',...
		'Upper Limit','4e-6',...
		'position',[740,303,770,327])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem1/Limiteur couple',13,'roue  4e-6 Nn']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem1/Limiteur couple',13,'roue  4e-6 Nn']],...
		'position',[765,350,770,355])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem1/To Workspace4'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1/To Workspace4'],...
		'hide name',0,...
		'mat-name','cpl_roue',...
		'buffer','points_trace',...
		'position',[825,265,905,285])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[180,255;210,255])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[255,175;500,175])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[180,175;210,175])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[255,255;500,255])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[100,215;130,215])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[90,370;110,370])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[180,370;190,370])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[240,370;290,370])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[345,330;500,330])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[345,410;500,410])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[380,370;500,370])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[240,330;300,330])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[240,410;300,410])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[545,370;625,370;635,335])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[180,215;220,215])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[300,215;500,215])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[545,215;560,215;560,290;635,290])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[310,215;310,190;330,190])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[390,370;400,350])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[690,315;735,315])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[775,315;825,315])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem1'],[790,315;790,275;820,275])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem1'],...
		'Mask Display','COUPLE ROUE\n\nSUR LE TANGAGE\n\nSEUL')


%     Finished composite block 'UnNamed1/Subsystem/Subsystem1'.

set_param([sys,'/','UnNamed1/Subsystem/Subsystem1'],...
		'hide name',0,...
		'position',[270,284,480,371])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Rappel sur l''intgrale de q qui',13,'devrait reprsenter sensiblement',13,'l''angle de tangage']])
set_param([sys,'/',['UnNamed1/Subsystem/Rappel sur l''intgrale de q qui',13,'devrait reprsenter sensiblement',13,'l''angle de tangage']],...
		'position',[800,40,805,45])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Test d''arrt']])
set_param([sys,'/',['UnNamed1/Subsystem/Test d''arrt']],...
		'position',[805,100,810,105])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem/out_3'])
set_param([sys,'/','UnNamed1/Subsystem/out_3'],...
		'hide name',0,...
		'position',[775,260,795,280])


%     Subsystem  'UnNamed1/Subsystem/Subsystem3'.

new_system([sys,'/','UnNamed1/Subsystem/Subsystem3'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem3'],'Location',[309,604,1161,904])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem3/Vitesse roue',13,'en tours//mn']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem3/Vitesse roue',13,'en tours//mn']],...
		'position',[455,70,460,75])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/Subsystem3/in_1'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem3/in_1'],...
		'position',[20,125,40,145])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem3/Gain5'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem3/Gain5'],...
		'BackGround',7,...
		'Gain','1/jroue',...
		'position',[240,115,275,155])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Subsystem3/Vitesse roue ',13,'en rd//s']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem3/Vitesse roue ',13,'en rd//s']],...
		'position',[520,210,525,215])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem3/To Workspace5'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem3/To Workspace5'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vit_roue',...
		'buffer','points_trace',...
		'position',[515,120,595,150])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem3/To Workspace6'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem3/To Workspace6'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vitesseroue',...
		'buffer','points_trace',...
		'position',[455,179,600,211])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/Subsystem3/To Workspace7'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem3/To Workspace7'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','couple_roue',...
		'buffer','points_trace',...
		'position',[235,189,340,221])

add_block('built-in/Integrator',[sys,'/','UnNamed1/Subsystem/Subsystem3/Integrator2'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem3/Integrator2'],...
		'BackGround',7,...
		'Initial','rotation_initiale',...
		'position',[325,113,370,157])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Subsystem3/Gain3'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem3/Gain3'],...
		'Gain','30/pi',...
		'position',[445,118,470,152])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Subsystem/Subsystem3/Inversion',13,'signe',13,'(action//roue)',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem/Subsystem3/Inversion',13,'signe',13,'(action//roue)',13,'']],...
		'Gain','-1',...
		'position',[115,122,145,148])

add_block('built-in/Scope',[sys,'/','UnNamed1/Subsystem/Subsystem3/Scope'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem3/Scope'],...
		'Vgain','2000.000000',...
		'Hgain','4000.000000',...
		'Vmax','4000.000000',...
		'Hmax','8000.000000',...
		'Window',[39,580,681,1020],...
		'position',[630,95,660,125])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem/Subsystem3/Outport'])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem3/Outport'],...
		'position',[665,245,685,265])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem3'],[375,135;440,135])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem3'],[395,135;395,195;450,195])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem3'],[280,135;320,135])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem3'],[45,135;110,135])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem3'],[150,135;235,135])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem3'],[175,135;175,205;230,205])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem3'],[475,135;510,135])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem3'],[490,135;490,110;625,110])
add_line([sys,'/','UnNamed1/Subsystem/Subsystem3'],[395,195;395,255;660,255])
set_param([sys,'/','UnNamed1/Subsystem/Subsystem3'],...
		'Mask Display','EVOLUTION DE LA\nVITESSE DE LA ROUE')


%     Finished composite block 'UnNamed1/Subsystem/Subsystem3'.

set_param([sys,'/','UnNamed1/Subsystem/Subsystem3'],...
		'ForeGround',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[665,439,810,501])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem/Demux1'])
set_param([sys,'/','UnNamed1/Subsystem/Demux1'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'outputs','3',...
		'position',[590,443,635,497])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem/Couple total'])
set_param([sys,'/','UnNamed1/Subsystem/Couple total'],...
		'position',[640,144,665,391])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/Couple de contrle'])
set_param([sys,'/','UnNamed1/Subsystem/Couple de contrle'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[785,215,790,220])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Couple roue sur',13,'satellite']])
set_param([sys,'/',['UnNamed1/Subsystem/Couple roue sur',13,'satellite']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[465,440,470,445])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem/Outport'])
set_param([sys,'/','UnNamed1/Subsystem/Outport'],...
		'Port','2',...
		'position',[855,460,875,480])
add_line([sys,'/','UnNamed1/Subsystem'],[110,185;265,185])
add_line([sys,'/','UnNamed1/Subsystem'],[115,225;265,225])
add_line([sys,'/','UnNamed1/Subsystem'],[670,270;770,270])
add_line([sys,'/','UnNamed1/Subsystem'],[480,205;635,205])
add_line([sys,'/','UnNamed1/Subsystem'],[155,225;155,305;265,305])
add_line([sys,'/','UnNamed1/Subsystem'],[485,330;635,330])
add_line([sys,'/','UnNamed1/Subsystem'],[126,185;125,350;265,350])
add_line([sys,'/','UnNamed1/Subsystem'],[640,470;660,470])
add_line([sys,'/','UnNamed1/Subsystem'],[545,330;545,470;585,470])
add_line([sys,'/','UnNamed1/Subsystem'],[815,470;850,470])
set_param([sys,'/','UnNamed1/Subsystem'],...
		'Mask Display','ACQUISITION ROUE\n+\nUN MAGNETOCOUPLEUR\nSUR\nLE TANGAGE')


%     Finished composite block 'UnNamed1/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem'],...
		'hide name',0,...
		'position',[295,365,480,460])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],'Location',[4,207,1271,813])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[295,468,475,522])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain'])
set_param([sys,'/','UnNamed1/Gain'],...
		'hide name',0,...
		'position',[515,482,540,508])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum2'])
set_param([sys,'/','UnNamed1/Sum2'],...
		'position',[610,376,640,534])

add_block('built-in/Note',[sys,'/','UnNamed1/pqr'])
set_param([sys,'/','UnNamed1/pqr'],...
		'position',[220,180,225,185])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'outputs','[3 4]',...
		'position',[145,119,195,481])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport'])
set_param([sys,'/','UnNamed1/Inport'],...
		'position',[45,290,65,310])

add_block('built-in/Note',[sys,'/','UnNamed1/Q'])
set_param([sys,'/','UnNamed1/Q'],...
		'position',[260,365,265,370])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum'])
set_param([sys,'/','UnNamed1/Sum'],...
		'position',[615,161,640,354])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain5'])
set_param([sys,'/','UnNamed1/Gain5'],...
		'hide name',0,...
		'position',[535,293,590,317])

add_block('built-in/Note',[sys,'/',['UnNamed1/Supression ',13,'roue']])
set_param([sys,'/',['UnNamed1/Supression ',13,'roue']],...
		'position',[550,250,555,255])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/magneto.m2'])
set_param([sys,'/','UnNamed1/magneto.m2'],...
		'hide name',0,...
		'MATLAB Fcn','jw_rotot(u)',...
		'Output Width','3',...
		'Mask Display','Participation\nde la roue',...
		'position',[350,273,475,337])

add_block('built-in/Mux',[sys,'/','UnNamed1/Mux'])
set_param([sys,'/','UnNamed1/Mux'],...
		'inputs','[1 3]',...
		'position',[285,286,315,319])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/magneto.m1'])
set_param([sys,'/','UnNamed1/magneto.m1'],...
		'hide name',0,...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[310,183,480,237])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain2'])
set_param([sys,'/','UnNamed1/Gain2'],...
		'position',[565,402,590,428])

add_block('built-in/Note',[sys,'/',['UnNamed1/Vitesse',13,' roue']])
set_param([sys,'/',['UnNamed1/Vitesse',13,' roue']],...
		'position',[550,350,555,355])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum1'])
set_param([sys,'/','UnNamed1/Sum1'],...
		'position',[945,199,975,441])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain1'])
set_param([sys,'/','UnNamed1/Gain1'],...
		'position',[1015,307,1040,333])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[1075,310,1095,330])
add_line([sys,'/','UnNamed1'],[200,210;305,210])
add_line([sys,'/','UnNamed1'],[1045,320;1070,320])
add_line([sys,'/','UnNamed1'],[70,300;140,300])
add_line([sys,'/','UnNamed1'],[200,390;290,390])
add_line([sys,'/','UnNamed1'],[243,210;243,435;290,435])
add_line([sys,'/','UnNamed1'],[980,320;1010,320])
add_line([sys,'/','UnNamed1'],[480,495;510,495])
add_line([sys,'/','UnNamed1'],[100,300;100,495;290,495])
add_line([sys,'/','UnNamed1'],[815,380;855,380])
add_line([sys,'/','UnNamed1'],[545,495;605,495])
add_line([sys,'/','UnNamed1'],[645,455;665,455;665,380;705,380])
add_line([sys,'/','UnNamed1'],[595,415;605,415])
add_line([sys,'/','UnNamed1'],[905,380;940,380])
add_line([sys,'/','UnNamed1'],[645,260;940,260])
add_line([sys,'/','UnNamed1'],[480,305;530,305])
add_line([sys,'/','UnNamed1'],[485,210;610,210])
add_line([sys,'/','UnNamed1'],[595,305;610,305])
add_line([sys,'/','UnNamed1'],[320,305;345,305])
add_line([sys,'/','UnNamed1'],[243,310;280,310])
add_line([sys,'/','UnNamed1'],[485,435;520,435;520,350;260,350;260,295;280,295])
add_line([sys,'/','UnNamed1'],[485,390;505,390;505,415;560,415])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[185,303,410,387])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r);grid;figure(gcf)'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[135,780,340,841])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[640,700,815,756])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[220,519,822,812])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'MATLAB Fcn','stopderv(u)',...
		'Output Width','1',...
		'position',[55,63,115,97])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem2/Stop Simulation'],...
		'position',[350,63,390,97])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace'])
set_param([sys,'/','Subsystem2/To Workspace'],...
		'mat-name','stop',...
		'position',[370,27,420,43])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'BackGround',7,...
		'position',[185,63,265,97])

add_block('built-in/Note',[sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[345,140,350,145])
add_line([sys,'/','Subsystem2'],[40,80;50,80])
add_line([sys,'/','Subsystem2'],[120,80;180,80])
add_line([sys,'/','Subsystem2'],[270,80;345,80])
add_line([sys,'/','Subsystem2'],[300,80;300,35;365,35])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','STOP')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'orientation',2,...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[690,263,775,317])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'BackGround',7,...
		'position',[80,113,115,147])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[850,290,855,295])


%     Subsystem  'Subsystem3'.

new_system([sys,'/','Subsystem3'])
set_param([sys,'/','Subsystem3'],'Location',[184,206,1171,591])

add_block('built-in/Inport',[sys,'/','Subsystem3/in_1'])
set_param([sys,'/','Subsystem3/in_1'],...
		'position',[15,105,35,125])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux1'])
set_param([sys,'/','Subsystem3/Mux1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[370,100,395,160])

add_block('built-in/Demux',[sys,'/','Subsystem3/Demux'])
set_param([sys,'/','Subsystem3/Demux'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'outputs','[3 3]',...
		'position',[265,96,305,129])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem3/MATLAB Fcn'])
set_param([sys,'/','Subsystem3/MATLAB Fcn'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','pqrQ_V_P(u)',...
		'Output Width','6',...
		'position',[175,98,235,132])

add_block('built-in/Clock',[sys,'/','Subsystem3/Clock'])
set_param([sys,'/','Subsystem3/Clock'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[305,158,340,192])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace3'])
set_param([sys,'/','Subsystem3/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_init_GP',...
		'buffer','1',...
		'position',[655,213,755,237])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace2'])
set_param([sys,'/','Subsystem3/To Workspace2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','initpqrQ_GP',...
		'buffer','1',...
		'position',[660,316,775,344])

add_block('built-in/To File',[sys,'/','Subsystem3/To File'])
set_param([sys,'/','Subsystem3/To File'],...
		'hide name',0,...
		'File name','init_GP.mat',...
		'Matrix name','init_acqGP',...
		'position',[640,247,780,283])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux'])
set_param([sys,'/','Subsystem3/Mux'],...
		'inputs','[1 7]',...
		'position',[525,226,590,299])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace'])
set_param([sys,'/','Subsystem3/To Workspace'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','init_tmc_fin',...
		'buffer','1',...
		'position',[450,118,550,142])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace1'])
set_param([sys,'/','Subsystem3/To Workspace1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_init_tmcfin',...
		'buffer','1',...
		'position',[450,163,555,187])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux2'])
set_param([sys,'/','Subsystem3/Mux2'],...
		'inputs','[6 1]',...
		'position',[610,66,650,179])

add_block('built-in/To File',[sys,'/','Subsystem3/To File1'])
set_param([sys,'/','Subsystem3/To File1'],...
		'hide name',0,...
		'File name','init_fin.mat',...
		'Matrix name','init_mod_fin',...
		'position',[675,107,815,143])

add_block('built-in/Note',[sys,'/','Subsystem3/Sorties pour mode fin'])
set_param([sys,'/','Subsystem3/Sorties pour mode fin'],...
		'position',[890,110,895,115])

add_block('built-in/Note',[sys,'/',['Subsystem3/Sorties pour Acquisition ',13,'grossire']])
set_param([sys,'/',['Subsystem3/Sorties pour Acquisition ',13,'grossire']],...
		'position',[870,240,875,245])

add_block('built-in/Note',[sys,'/','Subsystem3/Transmission des valeurs finales'])
set_param([sys,'/','Subsystem3/Transmission des valeurs finales'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[450,15,455,20])
add_line([sys,'/','Subsystem3'],[345,175;445,175])
add_line([sys,'/','Subsystem3'],[400,130;445,130])
add_line([sys,'/','Subsystem3'],[310,120;325,120;325,115;365,115])
add_line([sys,'/','Subsystem3'],[310,105;340,105;340,145;365,145])
add_line([sys,'/','Subsystem3'],[240,115;260,115])
add_line([sys,'/','Subsystem3'],[40,115;170,115])
add_line([sys,'/','Subsystem3'],[365,175;365,245;520,245])
add_line([sys,'/','Subsystem3'],[595,265;635,265])
add_line([sys,'/','Subsystem3'],[110,115;110,330;655,330])
add_line([sys,'/','Subsystem3'],[300,330;300,280;520,280])
add_line([sys,'/','Subsystem3'],[365,225;650,225])
add_line([sys,'/','Subsystem3'],[420,175;420,150;605,150])
add_line([sys,'/','Subsystem3'],[425,130;425,95;605,95])
add_line([sys,'/','Subsystem3'],[655,125;670,125])
set_param([sys,'/','Subsystem3'],...
		'Mask Display','SORTIES DES CONDITIONS\nFINALES DEVANT SERVIR\nDE CONDITIONS INITIALES\nA LA FUTURE SIMULATION')


%     Finished composite block 'Subsystem3'.

set_param([sys,'/','Subsystem3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[900,382,1145,468])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Voir courbe\ncouple\nroue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,couple_roue);grid;figure(gcf)'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[865,695,1040,761])


%     Subsystem  'Extras12'.

new_system([sys,'/','Extras12'])
set_param([sys,'/','Extras12'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras12'],...
		'Mask Display','Voir courbe\nvitesse\nroue (tours/mn)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;figure(gcf)'')')


%     Finished composite block 'Extras12'.

set_param([sys,'/','Extras12'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[1055,695,1230,761])


%     Subsystem  'Subsystem4'.

new_system([sys,'/','Subsystem4'])
set_param([sys,'/','Subsystem4'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem4/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem4/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/','Subsystem4/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem4/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,65,500,70])

add_block('built-in/Note',[sys,'/',['Subsystem4/Pour la simulation principale c''est DERIVDAT.M']])
set_param([sys,'/',['Subsystem4/Pour la simulation principale c''est DERIVDAT.M']],...
		'Font Size',14,...
		'position',[410,90,415,95])

add_block('built-in/Note',[sys,'/',['Subsystem4/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']])
set_param([sys,'/',['Subsystem4/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']],...
		'Font Size',14,...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['Subsystem4/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem4/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem4/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem4/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/','Subsystem4/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem4/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem4/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem4/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem4/d) Lancer la simulation'])
set_param([sys,'/','Subsystem4/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem4/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem4/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem4/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem4/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem4/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem4/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem4/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem4/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem4/b) '])
set_param([sys,'/','Subsystem4/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem4/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem4/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem4/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem4/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem4/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem4/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem4/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem4/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem4/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])
set_param([sys,'/','Subsystem4'],...
		'Mask Display','LANCER L''ACQUISITION GROSSIERE',...
		'Mask Dialogue','eval(''regacqG2'');')


%     Finished composite block 'Subsystem4'.

set_param([sys,'/','Subsystem4'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[875,785,1225,821])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance derivdat.m']])
set_param([sys,'/',['L''initialisation',13,' lance derivdat.m']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[1015,590,1020,595])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''derivdat'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',4,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[905,500,1120,571])
add_line(sys,[790,420;810,420;810,575;100,575;100,490;180,490])
add_line(sys,[625,420;680,420])
add_line(sys,[415,345;555,345])
add_line(sys,[405,490;555,490])
add_line(sys,[810,420;810,320;900,320])
add_line(sys,[660,420;660,355;900,355])
add_line(sys,[100,490;100,345;180,345])
add_line(sys,[810,320;810,290;780,290])
add_line(sys,[810,425;895,425])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
