function [ret,x0,str,ts,xts]=boussol7(t,x,u,flag);
%BOUSSOL7	is the M-file description of the SIMULINK system named BOUSSOL7.
%	The block-diagram can be displayed by typing: BOUSSOL7.
%
%	SYS=BOUSSOL7(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes BOUSSOL7 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling BOUSSOL7 with a FLAG of zero:
%	[SIZES]=BOUSSOL7([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[4,50,1267,947])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    'instant_injection')
set_param(sys,'Stop time',     '10000')
set_param(sys,'Min step size', '0.1')
set_param(sys,'Max step size', '0.4')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['Vecteur d''tat de 7 composantes']])
set_param([sys,'/',['Vecteur d''tat de 7 composantes']],...
		'position',[385,485,390,490])


%     Subsystem  'UnNamed2'.

new_system([sys,'/','UnNamed2'])
set_param([sys,'/','UnNamed2'],'Location',[588,239,931,333])

add_block('built-in/Note',[sys,'/',['UnNamed2/Drive du quaternion d''attitude']])
set_param([sys,'/',['UnNamed2/Drive du quaternion d''attitude']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[185,5,190,10])

add_block('built-in/Outport',[sys,'/','UnNamed2/Outport'])
set_param([sys,'/','UnNamed2/Outport'],...
		'position',[260,45,280,65])

add_block('built-in/Inport',[sys,'/','UnNamed2/Inport'])
set_param([sys,'/','UnNamed2/Inport'],...
		'position',[80,45,100,65])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed2/deriv_qt.m'])
set_param([sys,'/','UnNamed2/deriv_qt.m'],...
		'MATLAB Fcn','deriv_qt(u)',...
		'Output Width','4',...
		'position',[150,39,220,71])
add_line([sys,'/','UnNamed2'],[225,55;255,55])
add_line([sys,'/','UnNamed2'],[105,55;145,55])
set_param([sys,'/','UnNamed2'],...
		'Mask Display','F(X , t)\n\nPOUR LE QUATERNION')


%     Finished composite block 'UnNamed2'.

set_param([sys,'/','UnNamed2'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[140,368,355,472])

add_block('built-in/Note',[sys,'/','3'])
set_param([sys,'/','3'],...
		'position',[535,255,540,260])

add_block('built-in/Note',[sys,'/','4'])
set_param([sys,'/','4'],...
		'position',[530,395,535,400])


%     Subsystem  'Extras5'.

new_system([sys,'/','Extras5'])
set_param([sys,'/','Extras5'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras5'],...
		'Mask Display','Voir les courbes\ndes angles (en degrs)',...
		'Mask Dialogue','eval(''plot(temps,roulis,temps,tangage,temps,lacet);grid;figure(gcf)'')')


%     Finished composite block 'Extras5'.

set_param([sys,'/','Extras5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[115,615,315,681])


%     Subsystem  'Extras7'.

new_system([sys,'/','Extras7'])
set_param([sys,'/','Extras7'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras7'],...
		'Mask Display','Voir les courbes\nvitesses angulaires\np, q, r (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,p,temps,q,temps,r);grid;figure(gcf)'')')


%     Finished composite block 'Extras7'.

set_param([sys,'/','Extras7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[115,685,320,746])


%     Subsystem  'Extras11'.

new_system([sys,'/','Extras11'])
set_param([sys,'/','Extras11'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras11'],...
		'Mask Display','Voir la vitesse angulaire\nde tangage seul (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,q);grid;figure(gcf)'')')


%     Finished composite block 'Extras11'.

set_param([sys,'/','Extras11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[115,750,320,811])


%     Subsystem  'Extras6'.

new_system([sys,'/','Extras6'])
set_param([sys,'/','Extras6'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras6'],...
		'Mask Display','Voir la courbe\n\nenergie absolue (J)',...
		'Mask Dialogue','eval(''plot(temps,energie);grid;figure(gcf)'')')


%     Finished composite block 'Extras6'.

set_param([sys,'/','Extras6'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[595,615,770,671])


%     Subsystem  'Extras16'.

new_system([sys,'/','Extras16'])
set_param([sys,'/','Extras16'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras16'],...
		'Mask Display','Voir la commande \navant le "hachoir "',...
		'Mask Dialogue','eval(''plot(temps,com_avant);grid;figure(gcf)'')')


%     Finished composite block 'Extras16'.

set_param([sys,'/','Extras16'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[780,615,980,681])


%     Subsystem  'Extras17'.

new_system([sys,'/','Extras17'])
set_param([sys,'/','Extras17'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras17'],...
		'Mask Display','Champs magntiques\nrel roulis\npuls linaire roulis',...
		'Mask Dialogue','eval(''plot(temps,b_reel_roulis,temps,b_pulse_roulis);grid;figure(gcf)'')')


%     Finished composite block 'Extras17'.

set_param([sys,'/','Extras17'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[995,610,1195,676])


%     Subsystem  'Extras19'.

new_system([sys,'/','Extras19'])
set_param([sys,'/','Extras19'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras19'],...
		'Mask Display','Champs magn drivs\nrel roulis\npuls constant roulis',...
		'Mask Dialogue','eval(''plot(temps,derb_reel_roulis,temps,derb_pulse_roulis);grid;figure(gcf)'')')


%     Finished composite block 'Extras19'.

set_param([sys,'/','Extras19'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[995,685,1195,751])


%     Subsystem  'Extras18'.

new_system([sys,'/','Extras18'])
set_param([sys,'/','Extras18'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras18'],...
		'Mask Display','Voir la commande \napres le "hachoir "',...
		'Mask Dialogue','eval(''plot(temps,com_apres);grid;figure(gcf)'')')


%     Finished composite block 'Extras18'.

set_param([sys,'/','Extras18'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[780,690,980,756])


%     Subsystem  'Subsystem4'.

new_system([sys,'/','Subsystem4'])
set_param([sys,'/','Subsystem4'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem4/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem4/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/','Subsystem4/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem4/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,65,500,70])

add_block('built-in/Note',[sys,'/',['Subsystem4/Pour la simulation principale c''est DERIVDAT.M']])
set_param([sys,'/',['Subsystem4/Pour la simulation principale c''est DERIVDAT.M']],...
		'Font Size',14,...
		'position',[410,90,415,95])

add_block('built-in/Note',[sys,'/',['Subsystem4/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']])
set_param([sys,'/',['Subsystem4/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']],...
		'Font Size',14,...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['Subsystem4/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem4/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem4/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem4/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/','Subsystem4/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem4/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem4/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem4/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem4/d) Lancer la simulation'])
set_param([sys,'/','Subsystem4/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem4/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem4/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem4/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem4/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem4/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem4/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem4/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem4/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem4/b) '])
set_param([sys,'/','Subsystem4/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem4/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem4/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem4/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem4/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem4/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem4/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem4/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem4/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem4/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])
set_param([sys,'/','Subsystem4'],...
		'Mask Display','LANCER L''ACQUISITION GROSSIERE',...
		'Mask Dialogue','eval(''regacqGP'');')


%     Finished composite block 'Subsystem4'.

set_param([sys,'/','Subsystem4'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[865,530,1215,566])

add_block('built-in/Note',[sys,'/',['L''initialisation',13,' lance laurdat1.m, puls par dfaut',13,'']])
set_param([sys,'/',['L''initialisation',13,' lance laurdat1.m, puls par dfaut',13,'']],...
		'BackGround',6,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[985,475,990,480])

add_block('built-in/Note',[sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'et un rappel proportionnel sur un champ de consigne, adapte au cas puls']])
set_param([sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'et un rappel proportionnel sur un champ de consigne, adapte au cas puls']],...
		'ForeGround',5,...
		'Font Weight','bold',...
		'Font Size',22)
set_param([sys,'/',['Stabilisation par la drive du champ magntique terrestre',13,'et un rappel proportionnel sur un champ de consigne, adapte au cas puls']],...
		'position',[653,50,658,55])

add_block('built-in/Note',[sys,'/','TECHNIQUE DE M LAURENS'])
set_param([sys,'/','TECHNIQUE DE M LAURENS'],...
		'position',[620,125,625,130])

add_block('built-in/Note',[sys,'/',['DETUMBLING AVEC QUATERNION D''ATTITUDE ',13,'',13,'',13,'']])
set_param([sys,'/',['DETUMBLING AVEC QUATERNION D''ATTITUDE ',13,'',13,'',13,'']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',26,...
		'position',[640,0,645,5])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[4,50,1258,735])
open_system([sys,'/','UnNamed1'])

add_block('built-in/Note',[sys,'/','UnNamed1/Q'])
set_param([sys,'/','UnNamed1/Q'],...
		'position',[295,440,300,445])

add_block('built-in/Note',[sys,'/','UnNamed1/pqr'])
set_param([sys,'/','UnNamed1/pqr'],...
		'position',[325,375,330,380])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'outputs','[3 4]',...
		'position',[225,375,275,495])

add_block('built-in/Note',[sys,'/',['UnNamed1/tau',13,'']])
set_param([sys,'/',['UnNamed1/tau',13,'']],...
		'position',[85,240,90,245])

add_block('built-in/Note',[sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Vecteur d''tat ',13,'7 composantes',13,'p q r Q']],...
		'position',[105,335,110,340])

add_block('built-in/Inport',[sys,'/','UnNamed1/Inport'])
set_param([sys,'/','UnNamed1/Inport'],...
		'position',[75,300,95,320])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace4'])
set_param([sys,'/','UnNamed1/To Workspace4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','quater',...
		'buffer','2500',...
		'position',[325,460,390,490])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression de',13,'toutes les',13,'perturbations']])
set_param([sys,'/',['UnNamed1/Suppression de',13,'toutes les',13,'perturbations']],...
		'position',[515,325,520,330])

add_block('built-in/Note',[sys,'/',['UnNamed1/F(X,t) POUR LA PARTIE CONCERNANT LA SEULE ROTATION',13,'AVEC LA METHODE INITIALE DE M LAURENS']])
set_param([sys,'/',['UnNamed1/F(X,t) POUR LA PARTIE CONCERNANT LA SEULE ROTATION',13,'AVEC LA METHODE INITIALE DE M LAURENS']],...
		'ForeGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',22)
set_param([sys,'/',['UnNamed1/F(X,t) POUR LA PARTIE CONCERNANT LA SEULE ROTATION',13,'AVEC LA METHODE INITIALE DE M LAURENS']],...
		'position',[630,40,635,45])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],'Location',[4,176,1271,782])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/B']],...
		'position',[510,425,515,430])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Vecteur d''tat',13,'7 composantes',13,'p q r Q']],...
		'position',[140,515,145,520])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain3']],...
		'hide name',0,...
		'Gain','-1',...
		'position',[800,382,835,408])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[880,399,885,404])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Couple arodynamique']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[690,277,695,282])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel1']],...
		'MATLAB Fcn','norm(u,2)',...
		'Output Width','1',...
		'position',[770,438,830,472])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Gain']],...
		'Gain','mom_magn_res',...
		'position',[375,315,490,365])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/To Workspace']],...
		'hide name',0,...
		'mat-name','moment_residuel',...
		'buffer','5000',...
		'position',[895,440,1015,470])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Moment magntique rsiduel']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[245,246,250,251])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Produit',13,'vectoriel']],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[640,378,700,412])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux5']],...
		'inputs','[3 3]',...
		'position',[540,286,585,504])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux3']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[320,288,350,392])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant12']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','alpha',...
		'position',[130,293,275,317])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant11']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','beta',...
		'position',[130,328,275,352])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant10']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','gamma',...
		'position',[130,363,275,387])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/M']],...
		'position',[525,315,530,320])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant6']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero3',...
		'position',[785,318,930,342])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant5']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero2',...
		'position',[785,283,930,307])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant4']],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Value','cpl_aero1',...
		'position',[785,248,930,272])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux1']],...
		'ForeGround',1,...
		'BackGround',0,...
		'inputs','3',...
		'position',[975,243,1005,347])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Termes rsidus de gradient',13,'et forces inertie']],...
		'ForeGround',4,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[895,195,900,200])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant3']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','Irt*vitesse_rotation^2',...
		'position',[795,158,940,182])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant2']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','3*Irl*vitesse_rotation^2',...
		'position',[795,123,940,147])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Constant1']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Value','-4*Itl*vitesse_rotation^2',...
		'position',[795,88,940,112])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Mux']],...
		'ForeGround',7,...
		'BackGround',0,...
		'inputs','3',...
		'position',[985,83,1015,187])


%     Subsystem  ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

new_system([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],'Location',[195,288,1041,757])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL',...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3',...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[220,120;245,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],[535,160;555,160])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Champ magntique',13,'en axes satellite']],...
		'position',[240,458,440,532])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'Font Size',16)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Ensemble des couples perturbateurs externes ou externes',13,'',13,'Il faut fournir les 3 composantes ',13,'du vecteur unitaire de la direction',13,'du moment magntique rsiduel ',13,'( si on le connat)']],...
		'position',[385,95,390,100])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Inport']],...
		'position',[20,485,40,505])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Sum']],...
		'inputs','++++',...
		'position',[1090,254,1125,361])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Outport']],...
		'position',[1200,300,1220,320])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[665,505,670,510])

add_block('built-in/Note',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/Partie principale du gradient de gravit']],...
		'position',[945,540,950,545])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','gradgrav(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1/MATLAB Fcn']],...
		'Mask Display','GRADIENT PRINCIPAL\n\nDE GRAVITE',...
		'position',[630,554,805,606])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[45,495;235,495])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[840,395;1055,395;1055,320;1085,320])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[705,395;735,395;735,455;765,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[735,395;795,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[835,455;890,455])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[590,395;635,395])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[445,495;470,495;470,450;535,450])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[495,340;535,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[355,340;370,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,305;315,305])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,340;315,340])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[280,375;315,375])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,100;980,100])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,135;980,135])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[945,170;980,170])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,260;970,260])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,295;970,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1010,295;1085,295])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[935,330;970,330])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1020,135;1075,135;1085,270])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[75,495;75,580;625,580])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[1130,310;1195,310])
add_line([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],[810,580;1070,580;1070,345;1085,345])
set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block ['UnNamed1/Perturbations',13,'arodynamiques1'].

set_param([sys,'/',['UnNamed1/Perturbations',13,'arodynamiques1']],...
		'ForeGround',2,...
		'hide name',0,...
		'position',[285,282,415,338])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain3'])
set_param([sys,'/','UnNamed1/Gain3'],...
		'hide name',0,...
		'position',[885,248,925,282])

add_block('built-in/State-Space',[sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']])
set_param([sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'A','[]',...
		'B','[]',...
		'C','[]',...
		'D','inv(Asat)',...
		'Mask Display','Inv(Asat)',...
		'Mask Type','Matrix Gain')
set_param([sys,'/',['UnNamed1/Matrix',13,'Gain',13,'applique',13,'aux couples',13,'externes']],...
		'Mask Help','Multiplies input vector by entered matrix to produce output vector (y=Au).',...
		'position',[745,242,845,288])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_1'])
set_param([sys,'/','UnNamed1/out_1'],...
		'position',[1125,325,1145,345])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain1'])
set_param([sys,'/','UnNamed1/Gain1'],...
		'hide name',0,...
		'position',[1070,322,1095,348])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum1'])
set_param([sys,'/','UnNamed1/Sum1'],...
		'position',[970,194,1010,476])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/magneto.m1'])
set_param([sys,'/','UnNamed1/magneto.m1'],...
		'hide name',0,...
		'MATLAB Fcn','derivrot(u)',...
		'Output Width','3',...
		'Mask Display','DERIVROT(u)',...
		'position',[610,379,735,431])

add_block('built-in/Note',[sys,'/',['UnNamed1/Suppression de',13,'tous les couples']])
set_param([sys,'/',['UnNamed1/Suppression de',13,'tous les couples']],...
		'position',[900,205,905,210])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain'])
set_param([sys,'/','UnNamed1/Gain'],...
		'hide name',0,...
		'position',[460,293,500,327])

add_block('built-in/Note',[sys,'/','UnNamed1/Couple roue unidimensionnel sur tangage'])
set_param([sys,'/','UnNamed1/Couple roue unidimensionnel sur tangage'],...
		'position',[705,485,710,490])

add_block('built-in/Note',[sys,'/','UnNamed1/Sortie vitesse roue'])
set_param([sys,'/','UnNamed1/Sortie vitesse roue'],...
		'position',[980,620,985,625])

add_block('built-in/Sum',[sys,'/','UnNamed1/Sum2'])
set_param([sys,'/','UnNamed1/Sum2'],...
		'hide name',0,...
		'position',[680,128,720,372])


%     Subsystem  'UnNamed1/Subsystem5'.

new_system([sys,'/','UnNamed1/Subsystem5'])
set_param([sys,'/','UnNamed1/Subsystem5'],'Location',[298,510,1135,815])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem5/out_1'])
set_param([sys,'/','UnNamed1/Subsystem5/out_1'],...
		'position',[635,140,655,160])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem5/To Workspace2'])
set_param([sys,'/','UnNamed1/Subsystem5/To Workspace2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','com_avant',...
		'buffer','points_trace',...
		'position',[205,38,295,52])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem5/Demux'])
set_param([sys,'/','UnNamed1/Subsystem5/Demux'],...
		'outputs','3',...
		'position',[140,39,180,71])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem5/in_1'])
set_param([sys,'/','UnNamed1/Subsystem5/in_1'],...
		'position',[65,100,85,120])


%     Subsystem  'UnNamed1/Subsystem5/Subsystem5'.

new_system([sys,'/','UnNamed1/Subsystem5/Subsystem5'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5'],'Location',[580,281,938,501])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem5/Subsystem5/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','valeur_creneau',...
		'buffer','points_trace',...
		'position',[245,178,340,192])

add_block('built-in/Clock',[sys,'/','UnNamed1/Subsystem5/Subsystem5/Clock'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/Clock'],...
		'BackGround',7,...
		'position',[45,113,80,147])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Subsystem5/Subsystem5/MATLAB Fcn'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/MATLAB Fcn'],...
		'MATLAB Fcn','creneau(u)',...
		'Output Width','1',...
		'position',[120,113,180,147])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem5/Subsystem5/in_1'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/in_1'],...
		'position',[115,75,135,95])

add_block('built-in/Product',[sys,'/','UnNamed1/Subsystem5/Subsystem5/Product'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/Product'],...
		'hide name',0,...
		'position',[230,64,250,151])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem5/Subsystem5/out_1'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/out_1'],...
		'position',[295,100,315,120])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem5/Subsystem5/CRENEAU'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/CRENEAU'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[155,25,160,30])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem5/Subsystem5/To Workspace4'])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5/To Workspace4'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_creneau',...
		'buffer','points_trace',...
		'position',[125,193,220,207])
add_line([sys,'/','UnNamed1/Subsystem5/Subsystem5'],[185,130;225,130])
add_line([sys,'/','UnNamed1/Subsystem5/Subsystem5'],[205,130;205,185;240,185])
add_line([sys,'/','UnNamed1/Subsystem5/Subsystem5'],[85,130;115,130])
add_line([sys,'/','UnNamed1/Subsystem5/Subsystem5'],[255,110;290,110])
add_line([sys,'/','UnNamed1/Subsystem5/Subsystem5'],[140,85;225,85])
add_line([sys,'/','UnNamed1/Subsystem5/Subsystem5'],[85,130;85,195;120,200])
set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5'],...
		'Mask Display','COUPURES\nMAGNETOMETRES\nDE MESURES')


%     Finished composite block 'UnNamed1/Subsystem5/Subsystem5'.

set_param([sys,'/','UnNamed1/Subsystem5/Subsystem5'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[190,84,315,136])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem5/Gain2'])
set_param([sys,'/','UnNamed1/Subsystem5/Gain2'],...
		'hide name',0,...
		'Gain','pulse',...
		'position',[340,90,475,130])

add_block('built-in/Sum',[sys,'/','UnNamed1/Subsystem5/Sum1'])
set_param([sys,'/','UnNamed1/Subsystem5/Sum1'],...
		'hide name',0,...
		'position',[525,69,545,231])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem5/Gain1'])
set_param([sys,'/','UnNamed1/Subsystem5/Gain1'],...
		'hide name',0,...
		'Gain','1-pulse',...
		'position',[230,170,365,210])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem5/To Workspace3'])
set_param([sys,'/','UnNamed1/Subsystem5/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','com_apres',...
		'buffer','points_trace',...
		'position',[580,23,675,37])

add_block('built-in/Demux',[sys,'/','UnNamed1/Subsystem5/Demux1'])
set_param([sys,'/','UnNamed1/Subsystem5/Demux1'],...
		'outputs','3',...
		'position',[505,24,545,56])
add_line([sys,'/','UnNamed1/Subsystem5'],[90,110;125,110;125,190;225,190])
add_line([sys,'/','UnNamed1/Subsystem5'],[105,110;105,55;135,55])
add_line([sys,'/','UnNamed1/Subsystem5'],[185,45;200,45])
add_line([sys,'/','UnNamed1/Subsystem5'],[550,150;630,150])
add_line([sys,'/','UnNamed1/Subsystem5'],[320,110;335,110])
add_line([sys,'/','UnNamed1/Subsystem5'],[370,190;520,190])
add_line([sys,'/','UnNamed1/Subsystem5'],[480,110;520,110])
add_line([sys,'/','UnNamed1/Subsystem5'],[90,110;185,110])
add_line([sys,'/','UnNamed1/Subsystem5'],[550,30;575,30])
add_line([sys,'/','UnNamed1/Subsystem5'],[480,110;480,40;500,40])
set_param([sys,'/','UnNamed1/Subsystem5'],...
		'Mask Display','PULSE\noui/non')


%     Finished composite block 'UnNamed1/Subsystem5'.

set_param([sys,'/','UnNamed1/Subsystem5'],...
		'hide name',0,...
		'position',[560,166,645,214])

add_block('built-in/Gain',[sys,'/','UnNamed1/Gain2'])
set_param([sys,'/','UnNamed1/Gain2'],...
		'position',[485,175,530,205])


%     Subsystem  'UnNamed1/Subsystem'.

new_system([sys,'/','UnNamed1/Subsystem'])
set_param([sys,'/','UnNamed1/Subsystem'],'Location',[506,195,1156,577])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']])
set_param([sys,'/',['UnNamed1/Subsystem/Inversion',13,'signe',13,'(action//roue)',13,'']],...
		'ForeGround',2,...
		'Gain','-1',...
		'position',[115,122,145,148])

add_block('built-in/Gain',[sys,'/','UnNamed1/Subsystem/Gain3'])
set_param([sys,'/','UnNamed1/Subsystem/Gain3'],...
		'ForeGround',2,...
		'Gain','30/pi',...
		'position',[445,118,470,152])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/To Workspace5'])
set_param([sys,'/','UnNamed1/Subsystem/To Workspace5'],...
		'ForeGround',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vit_roue',...
		'buffer','points_trace',...
		'position',[515,120,595,150])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Vitesse roue ',13,'en rd//s']])
set_param([sys,'/',['UnNamed1/Subsystem/Vitesse roue ',13,'en rd//s']],...
		'ForeGround',2,...
		'position',[520,210,525,215])

add_block('built-in/Inport',[sys,'/','UnNamed1/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Subsystem/in_1'],...
		'ForeGround',2,...
		'position',[20,125,40,145])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Vitesse roue',13,'en tours//mn']])
set_param([sys,'/',['UnNamed1/Subsystem/Vitesse roue',13,'en tours//mn']],...
		'ForeGround',2,...
		'position',[455,70,460,75])

add_block('built-in/Gain',[sys,'/',['UnNamed1/Subsystem/Inertie',13,'de la ',13,'roue']])
set_param([sys,'/',['UnNamed1/Subsystem/Inertie',13,'de la ',13,'roue']],...
		'ForeGround',2,...
		'BackGround',7,...
		'Gain','1/J_ROUE',...
		'position',[195,115,230,155])

add_block('built-in/Note',[sys,'/','UnNamed1/Subsystem/SUIVI DE LA ROUE'])
set_param([sys,'/','UnNamed1/Subsystem/SUIVI DE LA ROUE'],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[390,10,395,15])

add_block('built-in/Integrator',[sys,'/','UnNamed1/Subsystem/Integrator2'])
set_param([sys,'/','UnNamed1/Subsystem/Integrator2'],...
		'ForeGround',2,...
		'BackGround',7,...
		'Initial','rotation_initiale',...
		'position',[280,113,325,157])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Subsystem/To Workspace6'])
set_param([sys,'/','UnNamed1/Subsystem/To Workspace6'],...
		'ForeGround',2,...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','vitesseroue',...
		'buffer','points_trace',...
		'position',[445,179,590,211])

add_block('built-in/Outport',[sys,'/','UnNamed1/Subsystem/out_1'])
set_param([sys,'/','UnNamed1/Subsystem/out_1'],...
		'hide name',0,...
		'position',[610,330,630,350])

add_block('built-in/To File',[sys,'/','UnNamed1/Subsystem/To File'])
set_param([sys,'/','UnNamed1/Subsystem/To File'],...
		'ForeGround',2,...
		'File name','vit_roue.mat',...
		'Matrix name','vit_roue_rd_s',...
		'position',[455,247,570,273])

add_block('built-in/Note',[sys,'/',['UnNamed1/Subsystem/Sortie de la vitesse ',13,'de la roue']])
set_param([sys,'/',['UnNamed1/Subsystem/Sortie de la vitesse ',13,'de la roue']],...
		'position',[485,320,490,325])
add_line([sys,'/','UnNamed1/Subsystem'],[475,135;510,135])
add_line([sys,'/','UnNamed1/Subsystem'],[150,135;190,135])
add_line([sys,'/','UnNamed1/Subsystem'],[45,135;110,135])
add_line([sys,'/','UnNamed1/Subsystem'],[235,135;275,135])
add_line([sys,'/','UnNamed1/Subsystem'],[330,135;440,135])
add_line([sys,'/','UnNamed1/Subsystem'],[395,135;395,195;440,195])
add_line([sys,'/','UnNamed1/Subsystem'],[395,195;395,345;605,340])
add_line([sys,'/','UnNamed1/Subsystem'],[420,195;420,260;450,260])
set_param([sys,'/','UnNamed1/Subsystem'],...
		'Mask Display','EVOLUTION DE LA\nVITESSE DE LA ROUE')


%     Finished composite block 'UnNamed1/Subsystem'.

set_param([sys,'/','UnNamed1/Subsystem'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'position',[655,584,800,646])


%     Subsystem  'UnNamed1/Calcul des commandes, moments et roue'.

new_system([sys,'/','UnNamed1/Calcul des commandes, moments et roue'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue'],'Location',[4,50,1267,947])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/REGULATION PAR LA DERIVEE AVEC UN GAIN LINEAIRE',13,'ET UN RAPPEL PROPORTIONNEL SUR UN CHAMP MAGNETIQUE DE CONSIGNE']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/REGULATION PAR LA DERIVEE AVEC UN GAIN LINEAIRE',13,'ET UN RAPPEL PROPORTIONNEL SUR UN CHAMP MAGNETIQUE DE CONSIGNE']],...
		'Font Name','Arial',...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/REGULATION PAR LA DERIVEE AVEC UN GAIN LINEAIRE',13,'ET UN RAPPEL PROPORTIONNEL SUR UN CHAMP MAGNETIQUE DE CONSIGNE']],...
		'Font Size',18,...
		'position',[595,10,600,15])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'ForeGround',2,...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/NB : Dans le vol rel, le champ magntique est celui ',13,'rgnant  la position du satellite']],...
		'position',[605,82,610,87])


%     Subsystem  'UnNamed1/Calcul des commandes, moments et roue/Subsystem'.

new_system([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],'Location',[4,142,1264,682])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/To Workspace6'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/To Workspace6'],...
		'hide name',0,...
		'mat-name','couple_commande',...
		'buffer','points_trace',...
		'position',[1090,370,1210,400])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Couple roue ',13,'dimension 1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Couple roue ',13,'dimension 1']],...
		'position',[795,385,800,390])

add_block('built-in/Constant',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Constant4'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Constant4'],...
		'hide name',0,...
		'Value','0',...
		'position',[785,440,805,460])

add_block('built-in/Constant',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Constant3'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'position',[780,350,800,370])

add_block('built-in/Mux',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Mux5'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Mux5'],...
		'hide name',0,...
		'inputs','3',...
		'position',[850,337,880,473])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Couple roue',13,'dimension 3']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Couple roue',13,'dimension 3']],...
		'position',[920,425,925,430])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Cx Cy Cz'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Cx Cy Cz'],...
		'position',[255,358,260,363])

add_block('built-in/Demux',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Demux5'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Demux5'],...
		'hide name',0,...
		'outputs','3',...
		'position',[275,189,315,301])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/MATLAB Fcn'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/MATLAB Fcn'],...
		'MATLAB Fcn','saturmm(u)',...
		'Output Width','3',...
		'position',[560,168,620,202])

add_block('built-in/Demux',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Demux2'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Demux2'],...
		'hide name',0,...
		'outputs','3',...
		'position',[640,148,670,222])

add_block('built-in/Sum',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Sum3'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Sum3'],...
		'position',[940,239,965,406])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Moment cr par',13,'magntocoupleurs']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Moment cr par',13,'magntocoupleurs']],...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[865,158,870,163])

add_block('built-in/MATLAB Fcn',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/MATLAB Fcn1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/MATLAB Fcn1'],...
		'MATLAB Fcn','prodvect(u)',...
		'Output Width','3',...
		'position',[855,263,915,297])

add_block('built-in/Mux',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Mux2'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Mux2'],...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[805,210,835,345])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/To Workspace1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/To Workspace1'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','mz',...
		'buffer','points_trace',...
		'position',[740,228,785,242])

add_block('built-in/Fcn',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Fcn'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Fcn'],...
		'Expr','1/u',...
		'position',[345,120,385,140])


%     Subsystem  ['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product'].

new_system([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product']],'Location',[33,479,253,634])

add_block('built-in/Product',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product/Product']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product/Product']],...
		'position',[65,55,90,75])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product/Sum']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product/Sum']],...
		'inputs','+',...
		'position',[125,55,145,75])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product/out_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product/out_1']],...
		'position',[185,55,205,75])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product/in_2']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product/in_2']],...
		'Port','2',...
		'position',[15,90,35,110])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product/in_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product/in_1']],...
		'position',[15,25,35,45])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product']],[40,100;60,70])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product']],[40,35;60,60])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product']],[95,65;120,65])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product']],[150,65;180,65])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product']],...
		'Mask Display','.\n',...
		'Mask Type','Dot Product',...
		'Mask Dialogue','Inner (dot) product.\ny=sum(u1.*u2)')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product']],...
		'Mask Help','Computes the inner (dot) product of the inputs: sum(u1.*u2).  The inputs are vectors of the same length. Output is a scalar.')


%     Finished composite block ['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product'].

set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Inner',13,'Product']],...
		'position',[285,324,310,371])

add_block('built-in/Product',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Product2'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Product2'],...
		'position',[450,322,480,358])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/mz'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/mz'],...
		'position',[460,178,465,183])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Cr'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Cr'],...
		'position',[460,293,465,298])

add_block('built-in/Product',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Product'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Product'],...
		'position',[445,122,475,158])

add_block('built-in/Mux',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Mux6'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Mux6'],...
		'inputs','3',...
		'position',[510,118,540,252])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Moments magntiques',13,'des bobines']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Moments magntiques',13,'des bobines']],...
		'position',[590,73,595,78])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Limiteur de',13,'moments magntiques',13,'et de couple roue']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Limiteur de',13,'moments magntiques',13,'et de couple roue']],...
		'position',[635,243,640,248])

add_block('built-in/Mux',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Mux7'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Mux7'],...
		'hide name',0,...
		'inputs','3',...
		'position',[740,73,770,207])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/To Workspace3'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/To Workspace3'],...
		'BackGround',7,...
		'hide name',0,...
		'mat-name','mx',...
		'buffer','points_trace',...
		'position',[720,42,770,58])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/To Workspace9'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/To Workspace9'],...
		'BackGround',7,...
		'hide name',0,...
		'Font Size',14,...
		'mat-name','Cr',...
		'buffer','points_trace',...
		'position',[1070,469,1115,501])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Sortie couple roue'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Sortie couple roue'],...
		'position',[1125,440,1130,445])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Champ magntique rel '])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Champ magntique rel '],...
		'position',[470,398,475,403])

add_block('built-in/Outport',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/out_5'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/out_5'],...
		'position',[1205,315,1225,335])

add_block('built-in/Constant',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Constant'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Constant'],...
		'hide name',0,...
		'Value','0',...
		'position',[675,130,695,150])

add_block('built-in/Outport',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/out_3'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/out_3'],...
		'Port','2',...
		'position',[1210,410,1230,430])

add_block('built-in/Demux',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Demux4'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Demux4'],...
		'hide name',0,...
		'outputs','3',...
		'position',[280,79,320,181])

add_block('built-in/Product',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Product1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Product1'],...
		'position',[445,202,475,238])

add_block('built-in/Gain',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Gain3'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/Gain3'],...
		'Gain','-1',...
		'position',[335,198,380,222])

add_block('built-in/Inport',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/in_1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/in_1'],...
		'position',[185,120,205,140])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Chalmp magntique',13,'puls']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Chalmp magntique',13,'puls']],...
		'position',[175,75,180,80])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Couple ',13,'raliser']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem/Couple ',13,'raliser']],...
		'position',[180,190,185,195])

add_block('built-in/Inport',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/in_2'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/in_2'],...
		'Port','2',...
		'position',[175,235,195,255])

add_block('built-in/Inport',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/in_3'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/in_3'],...
		'Port','3',...
		'position',[180,415,200,435])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/To Workspace7'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem/To Workspace7'],...
		'hide name',0,...
		'mat-name','couple_roue',...
		'buffer','points_trace',...
		'position',[1000,510,1120,540])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[970,325;1200,325])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[980,325;1045,325;1045,385;1085,385])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[810,450;845,450])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[675,210;700,210;700,405;845,405])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[885,405;915,405;915,365;935,365])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[480,140;505,140])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[920,280;935,280])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[805,360;845,360])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[775,140;790,140;800,245])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[840,280;850,280])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[675,185;735,185])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[720,185;720,235;735,235])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[675,160;715,160;715,95;735,95])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[700,160;700,50;715,50])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[700,140;735,140])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[485,340;490,340;490,230;505,230])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[480,220;490,220;490,185;505,185])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[625,185;635,185])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[545,185;555,185])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[390,130;390,230;440,230])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[390,230;390,330;445,330])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[315,350;445,350])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[210,130;275,130])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[255,130;255,335;280,335])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[385,210;440,210])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[320,210;330,210])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[390,130;440,130])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[320,280;420,280;420,150;440,150])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[325,130;340,130])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[200,245;270,245])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[230,245;230,360;280,360])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[700,405;700,485;1065,485])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[1005,485;1005,420;1205,420])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[205,425;645,425;645,310;800,310])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],[910,405;925,405;925,525;995,525])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],...
		'Mask Display','CALCUL DES MOMENTS\nMAGNETIQUES\nET DU COUPLE ROUE')


%     Finished composite block 'UnNamed1/Calcul des commandes, moments et roue/Subsystem'.

set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem'],...
		'position',[470,171,685,279])

add_block('built-in/Inport',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/in_1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/in_1'],...
		'hide name',0,...
		'position',[120,215,140,235])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/pqrQ'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/pqrQ'],...
		'position',[135,180,140,185])

add_block('built-in/Outport',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/out_5'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/out_5'],...
		'hide name',0,...
		'position',[755,190,775,210])

add_block('built-in/Outport',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/out_7'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/out_7'],...
		'hide name',0,...
		'Port','2',...
		'position',[760,245,780,265])


%     Subsystem  'UnNamed1/Calcul des commandes, moments et roue/Subsystem1'.

new_system([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],'Location',[87,134,1250,719])
open_system([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'])


%     Subsystem  ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES'].

new_system([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],'Location',[442,254,1087,515])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/in_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/in_1']],...
		'hide name',0,...
		'position',[25,100,45,120])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/out_3']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/out_3']],...
		'hide name',0,...
		'Port','3',...
		'position',[360,130,380,150])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/out_2']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/out_2']],...
		'hide name',0,...
		'position',[360,70,380,90])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/out_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/out_1']],...
		'hide name',0,...
		'Port','2',...
		'position',[360,100,380,120])


%     Subsystem  ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem'].

new_system([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],'Location',[4,192,1154,487])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_3']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_3']],...
		'Port','3',...
		'position',[760,185,780,205])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_2']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_2']],...
		'Port','2',...
		'position',[760,145,780,165])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/out_1']],...
		'position',[760,105,780,125])


%     Subsystem  ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3'].

new_system([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],'Location',[154,322,1099,787])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_1']],...
		'position',[115,190,135,210])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ rel satellite']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ rel satellite']],...
		'position',[690,55,695,60])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ  liss']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ  liss']],...
		'position',[775,115,780,120])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive pulse non lisse']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive pulse non lisse']],...
		'position',[790,425,795,430])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_3']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_3']],...
		'position',[800,390,820,410])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_1']],...
		'Port','3',...
		'position',[780,45,800,65])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_2']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/out_2']],...
		'Port','2',...
		'position',[790,145,810,165])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Sum']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Sum']],...
		'hide name',0,...
		'position',[640,134,665,321])


%     Subsystem  ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE'].

new_system([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],'Location',[4,50,853,441])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_2']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_2']],...
		'Port','2',...
		'position',[95,250,115,270])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Temps courant',13,'de la simulation']],...
		'position',[70,295,75,300])


%     Subsystem  ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'].

new_system([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],'Location',[125,1114771,765,1115016])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'position',[175,70,180,75])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum1']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'MATLAB Fcn','fix(u/T)*T')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'Output Width','1')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T2']],...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum4']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Sum4']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4']],...
		'hide name',0,...
		'Value','instant_injection')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Constant4']],...
		'position',[165,154,270,176])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Calcul t-nT1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/Calcul t-nT1']],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/out_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/out_1']],...
		'position',[525,105,545,125])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/in_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem/in_1']],...
		'position',[245,115,265,135])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[325,145;360,145])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[345,145;345,85;470,85])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[275,165;290,165])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[430,145;470,145])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[500,115;520,115])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],[270,125;290,125])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem'].

set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Subsystem']],...
		'hide name',0,...
		'position',[155,236,295,284])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']],...
		'hide name',0,...
		'mat-name','der_seconde',...
		'buffer','20000')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace7']],...
		'position',[705,568,825,602])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau']],...
		'position',[785,211,790,216])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/B(n)']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/B(n)']],...
		'position',[620,196,625,201])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie de t-tinj-nT']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie de t-tinj-nT']],...
		'position',[395,310,400,315])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/out_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/out_1']],...
		'position',[715,215,735,235])

add_block('built-in/To File',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To File']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To File']],...
		'File name','derbchap.mat',...
		'Matrix name','derb_chapeau')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To File']],...
		'position',[635,134,730,166])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storderB(u)')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Partie',13,'entire n1']],...
		'Output Width','3',...
		'position',[515,208,575,242])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/in_1']],...
		'position',[105,135,125,155])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t-tinj -nT<=Ta']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t-tinj -nT<=Ta']],...
		'position',[390,290,395,295])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']],...
		'hide name',0,...
		'mat-name','derb_chapeau',...
		'buffer','20000')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/To Workspace5']],...
		'position',[630,268,750,302])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Constant1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Constant1']],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[325,189,360,211])

add_block('built-in/Relational Operator',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Relational',13,'Operator']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,168,400,292])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t--tinj -nT']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/t--tinj -nT']],...
		'position',[335,235,340,240])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Mux1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Mux1']],...
		'inputs','[3 1]',...
		'position',[455,206,485,239])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie B_prime']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Sortie B_prime']],...
		'position',[550,175,555,180])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Entre de dB//dt //xyz ']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/Entre de dB//dt //xyz ']],...
		'position',[355,115,360,120])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'ForeGround',3)
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/MESURE ECHANTILLONEE DE LA DERIVEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta']],...
		'position',[425,0,430,5])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'ForeGround',3)
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'Font Size',12)
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_lin est la valeur linarise conserve aprs la mesure']],...
		'position',[405,75,410,80])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'ForeGround',3)
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'Font Size',12)
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE/derb_chapeau est la valeur constante conserve aprs la mesure',13,'']],...
		'position',[420,45,425,50])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[120,260;150,260])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[580,225;710,225])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[595,225;595,150;630,150])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[595,225;595,285;625,285])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[490,225;510,225])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[405,230;450,230])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[365,200;370,200])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[130,145;430,145;430,215;450,215])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],[300,260;370,260])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],...
		'Mask Display','DERIVEE DE B\n\nMESUREE\n\nPERIODE n')


%     Finished composite block ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE'].

set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/DERIVEE MESUREE']],...
		'position',[310,260,445,340])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Calcul t-nT']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Calcul t-nT']],...
		'hide name',0,...
		'position',[410,385,415,390])

add_block('built-in/Product',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Product']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Product']],...
		'position',[535,227,560,323])


%     Subsystem  ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE'].

new_system([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],'Location',[198,215,1097,749])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_1']],...
		'Port','2',...
		'position',[615,220,635,240])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_3']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_3']],...
		'position',[615,100,635,120])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/in_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/in_1']],...
		'position',[65,210,85,230])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre de B(t) //xyz ']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre de B(t) //xyz ']],...
		'position',[115,180,120,185])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Calcul t-nT']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Calcul t-nT']],...
		'hide name',0,...
		'position',[265,430,270,435])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie champ B chapeau']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie champ B chapeau']],...
		'position',[620,180,625,185])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t - tinj- nT']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t - tinj- nT']],...
		'position',[335,350,340,355])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Entre du champ en axes satellite ',13,' l''instant t de la simulation',13,'']],...
		'position',[215,200,220,205])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Mux1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Mux1']],...
		'inputs','[3 1]',...
		'position',[445,211,475,244])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']],...
		'hide name',0,...
		'MATLAB Fcn','storcham(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Partie',13,'entire n1']],...
		'position',[505,213,565,247])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_2']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/out_2']],...
		'Port','3',...
		'position',[615,420,635,440])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace3']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace3']],...
		'mat-name','champ1',...
		'buffer','20000',...
		'position',[610,272,660,288])

add_block('built-in/Relational Operator',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Relational',13,'Operator']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Relational',13,'Operator']],...
		'hide name',0,...
		'position',[375,258,400,382])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Constant1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Constant1']],...
		'hide name',0,...
		'Value','Ta/2',...
		'position',[305,279,340,301])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie de to = t -tinj - nT']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Sortie de to = t -tinj - nT']],...
		'position',[585,385,590,390])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Temps courant',13,'de la simulation']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Temps courant',13,'de la simulation']],...
		'position',[75,280,80,285])


%     Subsystem  ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'].

new_system([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],'Location',[163,376,803,621])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/out_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/out_1']],...
		'position',[555,105,575,125])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'ForeGround',3)
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'Font Size',12)
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/CALCUL DE LA PARTIE FRACTIONNAIRE',13,'DE LA PERIODE ENTRE nT ET (n+1)T']],...
		'position',[315,0,320,5])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Le temps courant de la simulation',13,'commence  l''instant d''injection ']],...
		'position',[135,100,140,105])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum1']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[475,54,495,176])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'MATLAB Fcn','fix(u/T)*T')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'Output Width','1')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Partie entire ',13,'de (t-tinj)T',13,' X par T']],...
		'position',[365,128,425,162])

add_block('built-in/Sum',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum4']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Sum4']],...
		'hide name',0,...
		'inputs','+-',...
		'position',[295,107,320,183])

add_block('built-in/Constant',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4']],...
		'hide name',0,...
		'Value','instant_injection')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Constant4']],...
		'position',[165,154,270,176])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Calcul t-nT1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/Calcul t-nT1']],...
		'hide name',0,...
		'position',[460,206,465,211])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/in_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem/in_1']],...
		'position',[245,115,265,135])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[325,145;360,145])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[345,145;345,85;470,85])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[275,165;290,165])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[430,145;470,145])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[500,115;550,115])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],[270,125;290,125])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],...
		'Mask Display','Mise en place\ndes priodes')


%     Finished composite block ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem'].

set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Subsystem']],...
		'hide name',0,...
		'position',[115,326,255,374])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Clock2']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/Clock2']],...
		'hide name',0,...
		'position',[45,330,85,370])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace4']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/To Workspace4']],...
		'mat-name','temps',...
		'buffer','20000',...
		'position',[140,412,190,428])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t-nT']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/t-nT']],...
		'position',[930,355,935,360])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'ForeGround',3)
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Name','Arial')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Weight','bold')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'Font Size',14)
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE/MESURE ECHANTILLONEE DU CHAMP',13,'SUR LA PERIODE N, AU TEMPS to+Ta//2']],...
		'position',[360,5,365,10])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[90,220;440,220])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[390,220;390,110;610,110])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[90,350;90,420;135,420])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[90,350;110,350])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[345,290;370,290])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[570,230;610,230])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[590,230;590,280;605,280])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[405,320;430,320;440,235])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[480,230;500,230])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[260,350;285,350;285,430;610,430])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],[285,350;370,350])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],...
		'Mask Display','CHAMP MESURE\n\n periode n')


%     Finished composite block ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE'].

set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/CHAMP MESURE']],...
		'position',[300,165,435,235])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive B']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive B']],...
		'position',[495,270,500,275])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/derb_chapeau']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/derb_chapeau']],...
		'position',[535,335,540,340])

add_block('built-in/Derivative',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive de',13,'B relle']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Drive de',13,'B relle']],...
		'position',[230,262,285,298])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/t -tinj - nT']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/t -tinj - nT']],...
		'position',[500,225,505,230])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/B(n)']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/B(n)']],...
		'position',[535,175,540,180])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ magntique',13,'terrestre',13,'(repre satellite)']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Champ magntique',13,'terrestre',13,'(repre satellite)']],...
		'position',[130,120,135,125])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Temps']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Temps']],...
		'position',[130,285,135,290])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_2']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/in_2']],...
		'Port','2',...
		'position',[110,310,130,330])

add_block('built-in/Demux',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux']],...
		'outputs','3',...
		'position',[505,94,545,126])

add_block('built-in/Demux',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux1']],...
		'outputs','3',...
		'position',[680,349,720,381])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']],...
		'hide name',0,...
		'mat-name','b_reel_roulis',...
		'buffer','points_trace')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace4']],...
		'position',[580,84,660,116])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']],...
		'hide name',0,...
		'mat-name','derb_pulse_roulis',...
		'buffer','points_trace')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace6']],...
		'position',[755,339,870,371])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']],...
		'hide name',0,...
		'mat-name','champ_pulse',...
		'buffer','points_trace')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace5']],...
		'position',[745,213,865,247])

add_block('built-in/Demux',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux2']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux2']],...
		'outputs','3',...
		'position',[750,279,790,311])

add_block('built-in/Demux',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux3']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/Demux3']],...
		'outputs','3',...
		'position',[375,419,415,451])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']],...
		'hide name',0,...
		'mat-name','derb_reel_roulis',...
		'buffer','points_trace')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace8']],...
		'position',[460,409,540,441])

add_block('built-in/To Workspace',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']],...
		'hide name',0,...
		'mat-name','b_pulse_roulis',...
		'buffer','points_trace')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3/To Workspace7']],...
		'position',[825,266,925,304])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[670,230;740,230])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[685,230;685,155;785,155])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[450,300;530,300])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[475,300;475,400;795,400])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[440,175;465,175;465,55;775,55])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[135,320;305,320])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[290,280;305,280])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[565,275;635,275])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[440,225;455,225;455,250;530,250])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[440,200;580,200;580,180;635,180])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[140,200;295,200])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[275,200;190,200;190,280;225,280])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[465,110;500,110])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[615,400;615,365;675,365])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[550,100;575,100])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[725,355;750,355])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[795,285;820,285])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[710,230;710,295;745,295])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[420,425;455,425])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],[290,280;290,435;370,435])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'Mask Display','Champ rel\n&\nchamp mesur')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'Mask Help','Entre 1= champ satellite, entre 2=temps, sortie 1= champ satellite, sortie2= champ liss, sortie 3 = drive non lisse')


%     Finished composite block ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3'].

set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Subsystem3']],...
		'hide name',0,...
		'position',[595,97,730,213])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Drive pulse crneau(mesure )']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Drive pulse crneau(mesure )']],...
		'position',[930,100,935,105])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ puls liss linairement ( mesure )']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ puls liss linairement ( mesure )']],...
		'position',[950,140,955,145])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ rel']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ rel']],...
		'position',[870,185,875,190])


%     Subsystem  ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_'].

new_system([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],'Location',[382,182,1228,651])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'hide name',0,...
		'MATLAB Fcn','champmgn(u)')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'Mask Display','CHAMP MAGNETIQUE\nREPERE ORBITAL')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn3']],...
		'position',[250,95,425,145])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Clock']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Clock']],...
		'position',[180,104,215,136])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/BX BY BZ']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/BX BY BZ']],...
		'position',[340,70,345,75])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Vecteur d''tat ',13,'( 7 composantes)']],...
		'position',[70,235,75,240])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/in_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/in_1']],...
		'position',[50,190,70,210])

add_block('built-in/Outport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/out_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/out_1']],...
		'position',[705,150,725,170])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Sortie Bx By Bz']],...
		'position',[725,200,730,205])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Equateur au temps 0 s']],...
		'position',[150,75,155,80])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'MATLAB Fcn','champsat(u)',...
		'Output Width','3')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/MATLAB Fcn1']],...
		'position',[560,143,620,177])

add_block('built-in/Mux',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Mux1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_/Mux1']],...
		'inputs','[3 7]',...
		'position',[485,80,530,240])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[220,120;245,120])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[430,120;480,120])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[625,160;700,160])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[75,200;480,200])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],[535,160;555,160])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],...
		'Mask Display','CHAMP MAGNETIQUE EN\nAXES SATELLITE\nEntre=vecteur d''tat\nSortie Bx By Bz')


%     Finished composite block ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_'].

set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Champ magntique',13,'en axes satellite_']],...
		'position',[240,88,440,162])

add_block('built-in/Inport',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/in_1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/in_1']],...
		'position',[160,115,180,135])

add_block('built-in/Clock',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Clock']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem/Clock']],...
		'position',[150,168,190,202])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[195,185;590,185])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[735,115;755,115])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[735,155;755,155])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[735,195;755,195])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[185,125;235,125])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],[445,125;590,125])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],...
		'Mask Display','CHAMP ET DERIVEE\n\nPULSES + CHAMP REEL')


%     Finished composite block ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem'].

set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Subsystem']],...
		'hide name',0,...
		'position',[85,64,285,156])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Drive pulse crneau']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Drive pulse crneau']],...
		'position',[460,65,465,70])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Champ puls linaire']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Champ puls linaire']],...
		'position',[455,95,460,100])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Champ rel']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES/Champ rel']],...
		'position',[425,125,430,130])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],[290,80;355,80])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],[290,110;355,110])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],[290,140;355,140])
add_line([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],[50,110;80,110])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],...
		'Mask Display','CHAMP ET DERIVEE\n\nPULSES')


%     Finished composite block ['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES'].

set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/CHAMP ET DERIVEE',13,' PULSES']],...
		'position',[90,113,230,187])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/To Workspace4'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/To Workspace4'],...
		'hide name',0,...
		'mat-name','Bc',...
		'buffer','points_trace',...
		'position',[440,309,505,331])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Bc'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Bc'],...
		'position',[495,190,500,195])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Pulse crneau'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Pulse crneau'],...
		'position',[335,100,340,105])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/B '])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/B '],...
		'position',[515,145,520,150])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Puls',13,'linaire']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Puls',13,'linaire']],...
		'position',[365,130,370,135])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/B'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/B'],...
		'position',[270,195,275,200])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/B''c']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/B''c']],...
		'position',[525,230,530,235])

add_block('built-in/Derivative',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Derivative'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Derivative'],...
		'position',[465,249,510,271])

add_block('built-in/Mux',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Mux'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Mux'],...
		'hide name',0,...
		'inputs','[3 3 3 3]',...
		'position',[540,101,575,284])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/B''']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/B''']],...
		'position',[455,100,460,105])

add_block('built-in/Mux',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Mux3'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Mux3'],...
		'hide name',0,...
		'inputs','[3 7]',...
		'position',[285,204,320,286])

add_block('built-in/Inport',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/in_1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/in_1'],...
		'position',[40,140,60,160])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Entre vecteur d''tat ',13,'7 composantes p q r Q']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Entre vecteur d''tat ',13,'7 composantes p q r Q']],...
		'position',[150,220,155,225])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/To Workspace7'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/To Workspace7'],...
		'hide name',0,...
		'mat-name','couple_reduit',...
		'buffer','points_trace',...
		'position',[870,94,960,116])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Couple',13,'rduit']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Couple',13,'rduit']],...
		'MATLAB Fcn','laurensv(u)',...
		'Output Width','3',...
		'position',[775,88,835,122])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Couple',13,'C2']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Couple',13,'C2']],...
		'position',[820,270,825,275])

add_block('built-in/Sum',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Sum2'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Sum2'],...
		'hide name',0,...
		'position',[855,155,885,315])

add_block('built-in/Outport',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/out_1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/out_1'],...
		'Port','2',...
		'position',[970,225,990,245])

add_block('built-in/Outport',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/out_2'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/out_2'],...
		'Port','3',...
		'position',[975,340,995,360])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Champ rel'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Champ rel'],...
		'position',[870,355,875,360])

add_block('built-in/Outport',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/out_3'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/out_3'],...
		'position',[965,40,985,60])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Champ puls'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Champ puls'],...
		'position',[830,25,835,30])

add_block('built-in/Product',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Product'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Product'],...
		'position',[640,377,665,428])

add_block('built-in/Fcn',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Fcn'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Fcn'],...
		'Expr','cos(u)',...
		'position',[575,380,615,400])

add_block('built-in/Product',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Product1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Product1'],...
		'position',[645,477,670,528])

add_block('built-in/Fcn',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Fcn1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Fcn1'],...
		'Expr','-sin(u)',...
		'position',[580,505,620,525])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Sur y'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Sur y'],...
		'position',[650,350,655,355])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Sur z'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Sur z'],...
		'position',[660,540,665,545])

add_block('built-in/Mux',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Mux4'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Mux4'],...
		'hide name',0,...
		'inputs','3',...
		'position',[730,378,760,532])

add_block('built-in/Constant',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Constant'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Constant'],...
		'Value','0',...
		'position',[690,395,710,415])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Couple C2 sur l''axe beta',13,'reconstruit sur x y z']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Couple C2 sur l''axe beta',13,'reconstruit sur x y z']],...
		'position',[800,535,805,540])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/To Workspace5'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/To Workspace5'],...
		'hide name',0,...
		'mat-name','Bc_prime',...
		'buffer','points_trace',...
		'position',[530,289,595,311])

add_block('built-in/Gain',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Gain2'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Gain2'],...
		'ForeGround',1,...
		'BackGround',2,...
		'Gain','gain_PD_laurens',...
		'position',[495,445,535,485])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Roulis'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Roulis'],...
		'position',[225,350,230,355])

add_block('built-in/Gain',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Gain3'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Gain3'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Gain','-1',...
		'position',[210,494,245,526])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Angles et drives',13,'de Cardan']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Angles et drives',13,'de Cardan']],...
		'ForeGround',1,...
		'BackGround',2,...
		'MATLAB Fcn','pqrQ_V_P(u)',...
		'Output Width','6')
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Angles et drives',13,'de Cardan']],...
		'position',[80,443,140,477])

add_block('built-in/Sum',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Sum3'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Sum3'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'inputs','-+',...
		'position',[305,393,320,442])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Lacet'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Lacet'],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[205,440,210,445])

add_block('built-in/Note',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/V_roulis'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/V_roulis'],...
		'ForeGround',1,...
		'BackGround',2,...
		'position',[210,465,215,470])

add_block('built-in/Demux',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Demux'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Demux'],...
		'ForeGround',1,...
		'BackGround',2,...
		'outputs','6',...
		'position',[155,356,180,559])

add_block('built-in/Constant',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Constant1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Constant1'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Value','consigne_tangage',...
		'position',[185,421,290,439])

add_block('built-in/Sum',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Sum1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Sum1'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[440,404,475,526])

add_block('built-in/Gain',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Gain'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Gain'],...
		'ForeGround',1,...
		'BackGround',2,...
		'Gain','K_PD_laurens',...
		'position',[355,418,420,452])

add_block('built-in/Gain',[sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Gain1'])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Gain1'],...
		'ForeGround',1,...
		'BackGround',2,...
		'Gain','F_PD_laurens',...
		'position',[340,483,415,507])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Couple',13,'C1']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Couple',13,'C1']],...
		'MATLAB Fcn','laurens1(u)',...
		'Output Width','3',...
		'position',[660,178,720,212])

add_block('built-in/MATLAB Fcn',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Champ Bc',13,'magntique',13,'de consigne',13,'']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Champ Bc',13,'magntique',13,'de consigne',13,'']],...
		'MATLAB Fcn','Bconsign(u)',...
		'Output Width','3',...
		'position',[345,228,405,262])

add_block('built-in/Note',[sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Couple',13,'',13,'raliser']])
set_param([sys,'/',['UnNamed1/Calcul des commandes, moments et roue/Subsystem1/Couple',13,'',13,'raliser']],...
		'position',[970,165,975,170])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[235,175;245,175;245,350;970,350])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[480,465;490,465])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[420,495;435,495])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[425,435;435,435])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[145,460;150,460])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[840,105;865,105])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[580,195;580,105;770,105])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[515,260;525,300])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[410,245;410,320;435,320])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[235,150;495,150;495,170;535,170])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[260,150;260,225;280,225])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[725,195;850,195])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[410,245;440,245;440,215;535,215])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[440,245;440,260;460,260])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[515,260;535,260])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[580,195;655,195])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[325,245;340,245])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[235,125;535,125])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[65,150;85,150])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[890,235;965,235])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[65,150;75,460])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[65,265;280,265])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[495,150;495,50;960,50])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[185,370;295,370;295,390;570,390])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[540,465;620,465;620,415;635,415])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[620,390;635,390])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[545,390;545,515;575,515])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[625,515;640,515])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[620,465;620,490;640,490])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[675,505;725,505])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[670,405;680,405;680,455;725,455])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[715,405;725,405])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[765,455;785,455;785,275;850,275])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[325,420;350,435])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[185,405;300,405])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[295,430;300,430])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[185,510;205,510])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],[250,510;300,510;300,495;335,495])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],...
		'Mask Display','CALCUL DES COUPLES\n\nC1 DE LAURENS ET C2')


%     Finished composite block 'UnNamed1/Calcul des commandes, moments et roue/Subsystem1'.

set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue/Subsystem1'],...
		'position',[195,174,410,276])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue'],[415,190;465,190])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue'],[415,225;465,225])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue'],[415,260;465,260])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue'],[145,225;190,225])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue'],[690,200;750,200])
add_line([sys,'/','UnNamed1/Calcul des commandes, moments et roue'],[690,255;755,255])
set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue'],...
		'Mask Display','REGULATION BOUSSOLE\n\nTECHNIQUE LAURENS\n\nPULSEE TYPE 2')


%     Finished composite block 'UnNamed1/Calcul des commandes, moments et roue'.

set_param([sys,'/','UnNamed1/Calcul des commandes, moments et roue'],...
		'position',[205,171,435,249])

add_block('built-in/Outport',[sys,'/','UnNamed1/out_2'])
set_param([sys,'/','UnNamed1/out_2'],...
		'Port','2',...
		'position',[1075,605,1095,625])
add_line([sys,'/','UnNamed1'],[420,310;455,310])
add_line([sys,'/','UnNamed1'],[280,405;605,405])
add_line([sys,'/','UnNamed1'],[280,465;310,465;320,475])
add_line([sys,'/','UnNamed1'],[1015,335;1065,335])
add_line([sys,'/','UnNamed1'],[1100,335;1120,335])
add_line([sys,'/','UnNamed1'],[100,310;280,310])
add_line([sys,'/','UnNamed1'],[190,310;190,435;220,435])
add_line([sys,'/','UnNamed1'],[190,310;200,210])
add_line([sys,'/','UnNamed1'],[505,310;675,310])
add_line([sys,'/','UnNamed1'],[725,250;740,265])
add_line([sys,'/','UnNamed1'],[850,265;880,265])
add_line([sys,'/','UnNamed1'],[930,265;965,265])
add_line([sys,'/','UnNamed1'],[740,405;965,405])
add_line([sys,'/','UnNamed1'],[535,190;555,190])
add_line([sys,'/','UnNamed1'],[650,190;675,190])
add_line([sys,'/','UnNamed1'],[440,230;580,230;580,615;650,615])
add_line([sys,'/','UnNamed1'],[805,615;1070,615])
add_line([sys,'/','UnNamed1'],[440,190;480,190])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','F(X , t ) \n\nPOUR LA ROTATION')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[145,203,370,287])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'hide name',0,...
		'inputs','[3 4]',...
		'position',[520,158,565,507])

add_block('built-in/Note',[sys,'/',['Entres',13,'drive rotation (3)']])
set_param([sys,'/',['Entres',13,'drive rotation (3)']],...
		'position',[455,160,460,165])

add_block('built-in/Note',[sys,'/','Drive quaternion (4)'])
set_param([sys,'/','Drive quaternion (4)'],...
		'position',[445,420,450,425])


%     Subsystem  'Couplage roue-satellite'.

new_system([sys,'/','Couplage roue-satellite'])
set_param([sys,'/','Couplage roue-satellite'],'Location',[90,50,975,400])

add_block('built-in/Note',[sys,'/','Couplage roue-satellite/CALCUL DU COUPLE DE COUPLAGE ROUE SATELLITE'])
set_param([sys,'/','Couplage roue-satellite/CALCUL DU COUPLE DE COUPLAGE ROUE SATELLITE'],...
		'ForeGround',3,...
		'BackGround',3,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[530,50,535,55])

add_block('built-in/Mux',[sys,'/','Couplage roue-satellite/Mux'])
set_param([sys,'/','Couplage roue-satellite/Mux'],...
		'inputs','[1 7]',...
		'position',[285,108,340,252])

add_block('built-in/Outport',[sys,'/','Couplage roue-satellite/out_1'])
set_param([sys,'/','Couplage roue-satellite/out_1'],...
		'position',[680,170,700,190])

add_block('built-in/Note',[sys,'/','Couplage roue-satellite/Vitesseroue'])
set_param([sys,'/','Couplage roue-satellite/Vitesseroue'],...
		'position',[190,105,195,110])

add_block('built-in/Note',[sys,'/',['Couplage roue-satellite/Sortie du couplage',13,'roue satellite']])
set_param([sys,'/',['Couplage roue-satellite/Sortie du couplage',13,'roue satellite']],...
		'position',[690,215,695,220])

add_block('built-in/MATLAB Fcn',[sys,'/','Couplage roue-satellite/magneto.m2'])
set_param([sys,'/','Couplage roue-satellite/magneto.m2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','jw_rotot(u)',...
		'Output Width','3',...
		'Mask Display','Participation\nde la roue\nau second membre')
set_param([sys,'/','Couplage roue-satellite/magneto.m2'],...
		'position',[390,156,530,204])

add_block('built-in/Gain',[sys,'/','Couplage roue-satellite/Gain1'])
set_param([sys,'/','Couplage roue-satellite/Gain1'],...
		'hide name',0,...
		'position',[595,167,620,193])

add_block('built-in/Note',[sys,'/','Couplage roue-satellite/pqrQ'])
set_param([sys,'/','Couplage roue-satellite/pqrQ'],...
		'position',[170,200,175,205])

add_block('built-in/Inport',[sys,'/','Couplage roue-satellite/in_4'])
set_param([sys,'/','Couplage roue-satellite/in_4'],...
		'Port','2',...
		'position',[190,204,215,226])

add_block('built-in/Inport',[sys,'/','Couplage roue-satellite/in_3'])
set_param([sys,'/','Couplage roue-satellite/in_3'],...
		'position',[185,135,205,155])

add_block('built-in/Note',[sys,'/','Couplage roue-satellite/Fonction jw_rotot.m'])
set_param([sys,'/','Couplage roue-satellite/Fonction jw_rotot.m'],...
		'position',[465,215,470,220])
add_line([sys,'/','Couplage roue-satellite'],[345,180;385,180])
add_line([sys,'/','Couplage roue-satellite'],[210,145;280,145])
add_line([sys,'/','Couplage roue-satellite'],[220,215;280,215])
add_line([sys,'/','Couplage roue-satellite'],[535,180;590,180])
add_line([sys,'/','Couplage roue-satellite'],[625,180;675,180])
set_param([sys,'/','Couplage roue-satellite'],...
		'Mask Display','COUPLAGE ROUE-SATELLITE')


%     Finished composite block 'Couplage roue-satellite'.

set_param([sys,'/','Couplage roue-satellite'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'position',[140,305,355,360])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'position',[440,205,465,280])

add_block('built-in/Integrator',[sys,'/','Integrator'])
set_param([sys,'/','Integrator'],...
		'hide name',0,...
		'Initial','[vp0 vq0 vr0 qt00 qt10 qt20 qt30]',...
		'position',[640,309,740,361])


%     Subsystem  'Subsystem'.

new_system([sys,'/','Subsystem'])
set_param([sys,'/','Subsystem'],'Location',[4,50,1260,942])

add_block('built-in/Note',[sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']])
set_param([sys,'/',['Subsystem/SORTIES ET TRAITEMENT DE LA SORTIE',13,'POUR VERIFICATIONS DE FONCTIONNALITE']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[620,40,625,45])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux'])
set_param([sys,'/','Subsystem/Demux'],...
		'outputs','[3 4]',...
		'position',[470,339,520,506])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn1'])
set_param([sys,'/','Subsystem/MATLAB Fcn1'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','angles(u)',...
		'Output Width','3',...
		'position',[700,448,760,482])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace14'])
set_param([sys,'/','Subsystem/To Workspace14'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[965,490,1035,510])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace12'])
set_param([sys,'/','Subsystem/To Workspace12'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[965,420,1035,440])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux2'])
set_param([sys,'/','Subsystem/Demux2'],...
		'outputs','3',...
		'position',[860,413,905,517])

add_block('built-in/Note',[sys,'/','Subsystem/Energie'])
set_param([sys,'/','Subsystem/Energie'],...
		'position',[885,390,890,395])

add_block('built-in/Note',[sys,'/','Subsystem/Drive de Q'])
set_param([sys,'/','Subsystem/Drive de Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[635,665,640,670])

add_block('built-in/Note',[sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']])
set_param([sys,'/',['Subsystem/Rotation atellite par',13,'rapport aux axes orbitaux']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[905,670,910,675])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn4'])
set_param([sys,'/','Subsystem/MATLAB Fcn4'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','omegaorb(u)',...
		'Output Width','3',...
		'position',[815,621,895,659])

add_block('built-in/Note',[sys,'/','Subsystem/Quaternion Q'])
set_param([sys,'/','Subsystem/Quaternion Q'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[600,435,605,440])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace5'])
set_param([sys,'/','Subsystem/To Workspace5'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','accel_angulaire',...
		'buffer','points_trace',...
		'position',[565,562,670,598])

add_block('built-in/Mux',[sys,'/','Subsystem/Mux'])
set_param([sys,'/','Subsystem/Mux'],...
		'inputs','[4 4]',...
		'position',[735,591,770,689])

add_block('built-in/Note',[sys,'/',['Subsystem/Q''']])
set_param([sys,'/',['Subsystem/Q''']],...
		'position',[710,670,715,675])

add_block('built-in/Note',[sys,'/','Subsystem/Q'])
set_param([sys,'/','Subsystem/Q'],...
		'position',[705,590,710,595])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace11'])
set_param([sys,'/','Subsystem/To Workspace11'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','omega_quat',...
		'buffer','points_trace',...
		'position',[915,624,1000,656])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace7'])
set_param([sys,'/','Subsystem/To Workspace7'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','energie',...
		'buffer','points_trace',...
		'position',[850,370,920,390])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem/MATLAB Fcn3'])
set_param([sys,'/','Subsystem/MATLAB Fcn3'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'MATLAB Fcn','ENERGIE(u)',...
		'Output Width','1',...
		'position',[745,361,825,399])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux1'])
set_param([sys,'/','Subsystem/Demux1'],...
		'outputs','[3 4]',...
		'position',[470,539,520,706])

add_block('built-in/Note',[sys,'/',['Subsystem/Entre de',13,'p q r Q']])
set_param([sys,'/',['Subsystem/Entre de',13,'p q r Q']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[420,365,425,370])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace13'])
set_param([sys,'/','Subsystem/To Workspace13'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[965,455,1035,475])

add_block('built-in/To File',[sys,'/','Subsystem/To File'])
set_param([sys,'/','Subsystem/To File'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','roulis',...
		'position',[1115,377,1205,423])

add_block('built-in/To File',[sys,'/','Subsystem/To File1'])
set_param([sys,'/','Subsystem/To File1'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','tangage',...
		'position',[1115,427,1205,473])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace8'])
set_param([sys,'/','Subsystem/To Workspace8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[965,525,1035,545])

add_block('built-in/To File',[sys,'/','Subsystem/To File2'])
set_param([sys,'/','Subsystem/To File2'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','lacet',...
		'position',[1115,492,1205,538])

add_block('built-in/To File',[sys,'/','Subsystem/To File3'])
set_param([sys,'/','Subsystem/To File3'],...
		'hide name',0,...
		'File name','angles.mat',...
		'Matrix name','temps',...
		'position',[1115,547,1205,593])

add_block('built-in/Clock',[sys,'/','Subsystem/Clock'])
set_param([sys,'/','Subsystem/Clock'],...
		'position',[905,525,925,545])

add_block('built-in/Demux',[sys,'/','Subsystem/Demux3'])
set_param([sys,'/','Subsystem/Demux3'],...
		'outputs','3',...
		'position',[610,158,655,262])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace15'])
set_param([sys,'/','Subsystem/To Workspace15'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','p',...
		'buffer','points_trace',...
		'position',[715,165,785,185])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace16'])
set_param([sys,'/','Subsystem/To Workspace16'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','q',...
		'buffer','points_trace',...
		'position',[715,200,785,220])

add_block('built-in/To Workspace',[sys,'/','Subsystem/To Workspace17'])
set_param([sys,'/','Subsystem/To Workspace17'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'mat-name','r',...
		'buffer','points_trace',...
		'position',[715,235,785,255])

add_block('built-in/Note',[sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']])
set_param([sys,'/',['Subsystem/Vitesses angulaires absolues',13,'autour des axes x y z']],...
		'position',[895,185,900,190])

add_block('built-in/Inport',[sys,'/','Subsystem/in_2'])
set_param([sys,'/','Subsystem/in_2'],...
		'Port','2',...
		'position',[390,615,410,635])

add_block('built-in/Gain',[sys,'/',['Subsystem/Conversion',13,'rd // degrs']])
set_param([sys,'/',['Subsystem/Conversion',13,'rd // degrs']],...
		'Gain','180/pi',...
		'position',[780,452,805,478])


%     Subsystem  ['Subsystem/Vitesses angulaires',13,'rd//s'].

new_system([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s/x']])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s/x']],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],[90,65;125,65])
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'Mask Entries','5000\/-0.2\/0.2\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block ['Subsystem/Vitesses angulaires',13,'rd//s'].

set_param([sys,'/',['Subsystem/Vitesses angulaires',13,'rd//s']],...
		'orientation',2,...
		'BackGround',2,...
		'position',[365,192,475,228])


%     Subsystem  'Subsystem/Angles en degrs'.

new_system([sys,'/','Subsystem/Angles en degrs'])
set_param([sys,'/','Subsystem/Angles en degrs'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Subsystem/Angles en degrs/x'])
set_param([sys,'/','Subsystem/Angles en degrs/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Subsystem/Angles en degrs/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Subsystem/Angles en degrs/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Subsystem/Angles en degrs'],[90,65;125,65])
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Subsystem/Angles en degrs'],...
		'Mask Entries','5000\/-200\/200\/''y-/g--/c-./w:/m*/ro/b+''\/')


%     Finished composite block 'Subsystem/Angles en degrs'.

set_param([sys,'/','Subsystem/Angles en degrs'],...
		'orientation',2,...
		'BackGround',2,...
		'position',[705,522,815,558])

add_block('built-in/Inport',[sys,'/','Subsystem/in_1'])
set_param([sys,'/','Subsystem/in_1'],...
		'position',[290,415,310,435])
add_line([sys,'/','Subsystem'],[525,380;740,380])
add_line([sys,'/','Subsystem'],[830,380;845,380])
add_line([sys,'/','Subsystem'],[315,425;465,425])
add_line([sys,'/','Subsystem'],[525,465;695,465])
add_line([sys,'/','Subsystem'],[930,535;960,535])
add_line([sys,'/','Subsystem'],[415,625;465,625])
add_line([sys,'/','Subsystem'],[525,580;560,580])
add_line([sys,'/','Subsystem'],[525,665;730,665])
add_line([sys,'/','Subsystem'],[675,465;675,615;730,615])
add_line([sys,'/','Subsystem'],[775,640;810,640])
add_line([sys,'/','Subsystem'],[900,640;910,640])
add_line([sys,'/','Subsystem'],[765,465;775,465])
add_line([sys,'/','Subsystem'],[810,465;855,465])
add_line([sys,'/','Subsystem'],[910,430;960,430])
add_line([sys,'/','Subsystem'],[910,465;960,465])
add_line([sys,'/','Subsystem'],[910,500;960,500])
add_line([sys,'/','Subsystem'],[945,430;945,400;1110,400])
add_line([sys,'/','Subsystem'],[943,465;945,450;1110,450])
add_line([sys,'/','Subsystem'],[945,500;945,515;1110,515])
add_line([sys,'/','Subsystem'],[930,535;930,570;1110,570])
add_line([sys,'/','Subsystem'],[550,380;550,210;605,210])
add_line([sys,'/','Subsystem'],[660,175;710,175])
add_line([sys,'/','Subsystem'],[660,210;710,210])
add_line([sys,'/','Subsystem'],[660,245;710,245])
add_line([sys,'/','Subsystem'],[550,210;480,210])
add_line([sys,'/','Subsystem'],[840,465;840,540;820,540])
set_param([sys,'/','Subsystem'],...
		'Mask Display','SORTIE DES ANGLES\n\nEN DEGRES & ENERGIE')


%     Finished composite block 'Subsystem'.

set_param([sys,'/','Subsystem'],...
		'hide name',0,...
		'position',[860,185,1090,265])

add_block('built-in/Note',[sys,'/',['p'' q'' r'' Q''']])
set_param([sys,'/',['p'' q'' r'' Q''']],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[805,240,810,245])

add_block('built-in/Note',[sys,'/','p q r Q'])
set_param([sys,'/','p q r Q'],...
		'Font Weight','bold',...
		'Font Size',12,...
		'position',[805,175,810,180])


%     Subsystem  'Subsystem2'.

new_system([sys,'/','Subsystem2'])
set_param([sys,'/','Subsystem2'],'Location',[559,482,1161,775])

add_block('built-in/Inport',[sys,'/','Subsystem2/in_1'])
set_param([sys,'/','Subsystem2/in_1'],...
		'position',[15,70,35,90])

add_block('built-in/MATLAB Fcn',[sys,'/',['Subsystem2/fonction ',13,'d''arrt']])
set_param([sys,'/',['Subsystem2/fonction ',13,'d''arrt']],...
		'MATLAB Fcn','stopderv(u)',...
		'Output Width','1',...
		'position',[55,63,115,97])

add_block('built-in/Stop Simulation',[sys,'/','Subsystem2/Stop Simulation'])
set_param([sys,'/','Subsystem2/Stop Simulation'],...
		'position',[350,63,390,97])

add_block('built-in/To Workspace',[sys,'/','Subsystem2/To Workspace'])
set_param([sys,'/','Subsystem2/To Workspace'],...
		'mat-name','stop',...
		'position',[370,27,420,43])

add_block('built-in/Gain',[sys,'/','Subsystem2/Gain'])
set_param([sys,'/','Subsystem2/Gain'],...
		'BackGround',7,...
		'position',[185,63,265,97])

add_block('built-in/Note',[sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'])
set_param([sys,'/','Subsystem2/Pour mettre le stop hors course, fixer le gain  0'],...
		'ForeGround',7,...
		'Font Name','Arial',...
		'Font Size',18,...
		'position',[345,140,350,145])
add_line([sys,'/','Subsystem2'],[40,80;50,80])
add_line([sys,'/','Subsystem2'],[120,80;180,80])
add_line([sys,'/','Subsystem2'],[270,80;345,80])
add_line([sys,'/','Subsystem2'],[300,80;300,35;365,35])
set_param([sys,'/','Subsystem2'],...
		'Mask Display','STOP')


%     Finished composite block 'Subsystem2'.

set_param([sys,'/','Subsystem2'],...
		'orientation',2,...
		'ForeGround',5,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',16,...
		'position',[640,178,725,232])


%     Subsystem  'Subsystem3'.

new_system([sys,'/','Subsystem3'])
set_param([sys,'/','Subsystem3'],'Location',[184,206,1171,591])

add_block('built-in/Inport',[sys,'/','Subsystem3/in_1'])
set_param([sys,'/','Subsystem3/in_1'],...
		'position',[15,105,35,125])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux1'])
set_param([sys,'/','Subsystem3/Mux1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'inputs','[3 3]',...
		'position',[370,100,395,160])

add_block('built-in/Demux',[sys,'/','Subsystem3/Demux'])
set_param([sys,'/','Subsystem3/Demux'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'outputs','[3 3]',...
		'position',[265,96,305,129])

add_block('built-in/MATLAB Fcn',[sys,'/','Subsystem3/MATLAB Fcn'])
set_param([sys,'/','Subsystem3/MATLAB Fcn'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'MATLAB Fcn','pqrQ_V_P(u)',...
		'Output Width','6',...
		'position',[175,98,235,132])

add_block('built-in/Clock',[sys,'/','Subsystem3/Clock'])
set_param([sys,'/','Subsystem3/Clock'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'position',[305,158,340,192])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace3'])
set_param([sys,'/','Subsystem3/To Workspace3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_init_GP',...
		'buffer','1',...
		'position',[655,213,755,237])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace2'])
set_param([sys,'/','Subsystem3/To Workspace2'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','initpqrQ_GP',...
		'buffer','1',...
		'position',[660,316,775,344])

add_block('built-in/To File',[sys,'/','Subsystem3/To File'])
set_param([sys,'/','Subsystem3/To File'],...
		'hide name',0,...
		'File name','init_GP.mat',...
		'Matrix name','init_acqGP',...
		'position',[640,247,780,283])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux'])
set_param([sys,'/','Subsystem3/Mux'],...
		'inputs','[1 7]',...
		'position',[525,226,590,299])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace'])
set_param([sys,'/','Subsystem3/To Workspace'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','init_tmc_fin',...
		'buffer','1',...
		'position',[450,118,550,142])

add_block('built-in/To Workspace',[sys,'/','Subsystem3/To Workspace1'])
set_param([sys,'/','Subsystem3/To Workspace1'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'mat-name','temps_init_tmcfin',...
		'buffer','1',...
		'position',[450,163,555,187])

add_block('built-in/Mux',[sys,'/','Subsystem3/Mux2'])
set_param([sys,'/','Subsystem3/Mux2'],...
		'inputs','[6 1]',...
		'position',[610,66,650,179])

add_block('built-in/To File',[sys,'/','Subsystem3/To File1'])
set_param([sys,'/','Subsystem3/To File1'],...
		'hide name',0,...
		'File name','init_fin.mat',...
		'Matrix name','init_mod_fin',...
		'position',[675,107,815,143])

add_block('built-in/Note',[sys,'/','Subsystem3/Sorties pour mode fin'])
set_param([sys,'/','Subsystem3/Sorties pour mode fin'],...
		'position',[890,110,895,115])

add_block('built-in/Note',[sys,'/',['Subsystem3/Sorties pour Acquisition ',13,'grossire']])
set_param([sys,'/',['Subsystem3/Sorties pour Acquisition ',13,'grossire']],...
		'position',[870,240,875,245])

add_block('built-in/Note',[sys,'/','Subsystem3/Transmission des valeurs finales'])
set_param([sys,'/','Subsystem3/Transmission des valeurs finales'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[450,15,455,20])
add_line([sys,'/','Subsystem3'],[345,175;445,175])
add_line([sys,'/','Subsystem3'],[400,130;445,130])
add_line([sys,'/','Subsystem3'],[310,120;325,120;325,115;365,115])
add_line([sys,'/','Subsystem3'],[310,105;340,105;340,145;365,145])
add_line([sys,'/','Subsystem3'],[240,115;260,115])
add_line([sys,'/','Subsystem3'],[40,115;170,115])
add_line([sys,'/','Subsystem3'],[365,175;365,245;520,245])
add_line([sys,'/','Subsystem3'],[595,265;635,265])
add_line([sys,'/','Subsystem3'],[110,115;110,330;655,330])
add_line([sys,'/','Subsystem3'],[300,330;300,280;520,280])
add_line([sys,'/','Subsystem3'],[365,225;650,225])
add_line([sys,'/','Subsystem3'],[420,175;420,150;605,150])
add_line([sys,'/','Subsystem3'],[425,130;425,95;605,95])
add_line([sys,'/','Subsystem3'],[655,125;670,125])
set_param([sys,'/','Subsystem3'],...
		'Mask Display','SORTIES DES CONDITIONS\nFINALES DEVANT SERVIR\nDE CONDITIONS INITIALES\nA LA FUTURE SIMULATION')


%     Finished composite block 'Subsystem3'.

set_param([sys,'/','Subsystem3'],...
		'ForeGround',1,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',12,...
		'position',[855,292,1100,378])


%     Subsystem  'Extras9'.

new_system([sys,'/','Extras9'])
set_param([sys,'/','Extras9'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras9'],...
		'Mask Display','Voir les courbes\nmoments magntiques\nmx,mz',...
		'Mask Dialogue','eval(''plot(temps,mx,temps,mz);grid;figure(gcf)'')')


%     Finished composite block 'Extras9'.

set_param([sys,'/','Extras9'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[350,615,575,676])


%     Subsystem  'Extras10'.

new_system([sys,'/','Extras10'])
set_param([sys,'/','Extras10'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras10'],...
		'Mask Display','Couleurs des courbes\nroulis=jaune\ntangage=bleu\nlacet=magenta')


%     Finished composite block 'Extras10'.

set_param([sys,'/','Extras10'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[355,685,585,771])

add_block('built-in/Note',[sys,'/','1  3 = rotation inertielle'])
set_param([sys,'/','1  3 = rotation inertielle'],...
		'position',[200,500,205,505])

add_block('built-in/Note',[sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']])
set_param([sys,'/',['4  7 = quaternion d''attitude dans le repre orbital']],...
		'position',[605,505,610,510])


%     Subsystem  'Subsystem1'.

new_system([sys,'/','Subsystem1'])
set_param([sys,'/','Subsystem1'],'Location',[10,115,1238,841])

add_block('built-in/Note',[sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'])
set_param([sys,'/','Subsystem1/COMMENT UTILISER LA SIMULATION'],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',20,...
		'position',[625,10,630,15])

add_block('built-in/Note',[sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'])
set_param([sys,'/','Subsystem1/1 - Le choix des paramtres doit tre ralis dans un fichier  ouvrir dans notepad (ou autre)'],...
		'Font Size',14,...
		'position',[495,65,500,70])

add_block('built-in/Note',[sys,'/',['Subsystem1/Pour la simulation principale c''est DERIVDAT.M']])
set_param([sys,'/',['Subsystem1/Pour la simulation principale c''est DERIVDAT.M']],...
		'Font Size',14,...
		'position',[410,90,415,95])

add_block('built-in/Note',[sys,'/',['Subsystem1/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']])
set_param([sys,'/',['Subsystem1/Pour la simulation orbite polaire et ces particulier d''une matrice d''inertie de revolution autour du tangage, c''est POLEDAT.M']],...
		'Font Size',14,...
		'position',[710,115,715,120])

add_block('built-in/Note',[sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']])
set_param([sys,'/',['Subsystem1/a) Un CLEAR dans l''espace Matlab est conseill']],...
		'Font Size',14,...
		'position',[405,185,410,190])

add_block('built-in/Note',[sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'])
set_param([sys,'/','Subsystem1/b) Cliquer sur le cadre magenta pour excuter le fichier de donnes derivdat ou poledat'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[560,210,565,215])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'])
set_param([sys,'/','Subsystem1/c) Paramtrer la simulation, choisir un temps assez long disons 30000 secondes'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[530,235,535,240])

add_block('built-in/Note',[sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']])
set_param([sys,'/',['Subsystem1/2 - Le lancement de la simulation principale se fait dans l''ordre suivant;']],...
		'Font Size',14,...
		'position',[405,160,410,165])

add_block('built-in/Note',[sys,'/','Subsystem1/d) Lancer la simulation'])
set_param([sys,'/','Subsystem1/d) Lancer la simulation'],...
		'Font Size',14,...
		'position',[295,265,300,270])

add_block('built-in/Note',[sys,'/','Subsystem1/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'])
set_param([sys,'/','Subsystem1/3 - Attendre que le stop arrte les calculs quand les vitesses sont suffisamment rduites,'],...
		'Font Size',14,...
		'position',[480,295,485,300])

add_block('built-in/Note',[sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'])
set_param([sys,'/','Subsystem1/NB :Le stop peut tre inactiv en portant son gain  0, dans son masque'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[495,325,500,330])

add_block('built-in/Note',[sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'])
set_param([sys,'/','Subsystem1/4 - Comment voir rapidement les courbes intressantes :'],...
		'Font Name','Arial',...
		'Font Underline',1,...
		'Font Size',14,...
		'position',[360,370,365,375])

add_block('built-in/Note',[sys,'/','Subsystem1/a) En cliquant dans les boites vertes'])
set_param([sys,'/','Subsystem1/a) En cliquant dans les boites vertes'],...
		'Font Size',14,...
		'position',[355,400,360,405])

add_block('built-in/Note',[sys,'/','Subsystem1/b) '])
set_param([sys,'/','Subsystem1/b) '],...
		'Font Size',14,...
		'position',[220,435,225,440])

add_block('built-in/Note',[sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']])
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'Font Name','Arial',...
		'Font Size',14)
set_param([sys,'/',['Subsystem1/Les sorties suivantes sont disponibles dans l''espace Matlab p q r roulis lacet tangage energie p2q2 ...',13,'(p+q = carr de la rotation transversale)']],...
		'position',[635,435,640,440])

add_block('built-in/Note',[sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'])
set_param([sys,'/','Subsystem1/c) Roulis lacet tangage temps sont aussi stockes dans angles.mat,  vous de les exploiter'],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[570,480,575,485])

add_block('built-in/Note',[sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']])
set_param([sys,'/',['Subsystem1/NB :Les couleurs lors de 3 sorties sont',13,' roulis jaune',13,'tangage magenta',13,'lacet cyan']],...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[580,545,585,550])

add_block('built-in/Note',[sys,'/','Subsystem1/Robert Guiziou dcembre 2013'])
set_param([sys,'/','Subsystem1/Robert Guiziou dcembre 2013'],...
		'position',[1115,690,1120,695])
set_param([sys,'/','Subsystem1'],...
		'Mask Display','LIRE LES EXPLICATIONS')


%     Finished composite block 'Subsystem1'.

set_param([sys,'/','Subsystem1'],...
		'ForeGround',7,...
		'BackGround',0,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[0,825,350,861])


%     Subsystem  'Extras13'.

new_system([sys,'/','Extras13'])
set_param([sys,'/','Extras13'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras13'],...
		'Mask Display','Voir courbe\nvitesse de la\n roue (rd/s)',...
		'Mask Dialogue','eval(''plot(temps,vit_roue);grid;figure(gcf)'')')


%     Finished composite block 'Extras13'.

set_param([sys,'/','Extras13'],...
		'BackGround',5,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[355,780,585,841])


%     Subsystem  'Extras8'.

new_system([sys,'/','Extras8'])
set_param([sys,'/','Extras8'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras8'],...
		'Mask Display','Voir courbe\ncouple de\ncommande (Nm)',...
		'Mask Dialogue','eval(''plot(temps,cpl_deriv);grid;figure(gcf)'')')


%     Finished composite block 'Extras8'.

set_param([sys,'/','Extras8'],...
		'ForeGround',1,...
		'BackGround',3,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[595,695,770,761])


%     Subsystem  'Extras12'.

new_system([sys,'/','Extras12'])
set_param([sys,'/','Extras12'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras12'],...
		'Mask Display','Voir courbe\ncouple commande\n roue (Nm)',...
		'Mask Dialogue','eval(''plot(temps,Cr);grid;figure(gcf)'')')


%     Finished composite block 'Extras12'.

set_param([sys,'/','Extras12'],...
		'BackGround',5,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[600,775,775,841])


%     Subsystem  'Extras20'.

new_system([sys,'/','Extras20'])
set_param([sys,'/','Extras20'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras20'],...
		'Mask Display','Voir la commande \napres le "hachoir "',...
		'Mask Dialogue','eval(''plot(temps,com_avant-com_apres);grid;figure(gcf)'')')


%     Finished composite block 'Extras20'.

set_param([sys,'/','Extras20'],...
		'ForeGround',1,...
		'BackGround',4,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Size',14,...
		'position',[785,770,985,836])


%     Subsystem  'Extras1'.

new_system([sys,'/','Extras1'])
set_param([sys,'/','Extras1'],'Location',[4,42,1012,678])
set_param([sys,'/','Extras1'],...
		'Mask Display','INITIALISATION\npar double clic souris\nCAS GENERAL',...
		'Mask Dialogue','eval(''laurdat1'')')


%     Finished composite block 'Extras1'.

set_param([sys,'/','Extras1'],...
		'ForeGround',1,...
		'BackGround',6,...
		'hide name',0,...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',14,...
		'position',[870,395,1070,461])

add_block('built-in/Note',[sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'])
set_param([sys,'/','Ci-dessous cliquer pour obtenir les tracs de courbes'],...
		'Font Name','Arial',...
		'Font Angle','italic',...
		'Font Size',16,...
		'position',[620,550,625,555])
add_line(sys,[745,335;765,335;765,505;55,505;55,420;135,420])
add_line(sys,[570,335;635,335])
add_line(sys,[360,420;515,420])
add_line(sys,[765,335;765,205;855,205])
add_line(sys,[615,335;615,245;855,245])
add_line(sys,[55,420;55,245;140,245])
add_line(sys,[765,205;730,205])
add_line(sys,[765,335;850,335])
add_line(sys,[375,225;435,225])
add_line(sys,[360,335;420,335;420,260;435,260])
add_line(sys,[470,245;515,245])
add_line(sys,[55,345;135,345])
add_line(sys,[375,265;385,265;385,295;115,295;115,320;135,320])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
